@@ -28,21 +28,24 @@ import org.jdesktop.animation.timing.TimingTargetAdapter;
 
 import docking.action.ActionContextProvider;
 import docking.action.DockingActionIf;
+import docking.actions.ActionAdapter;
+import docking.actions.KeyBindingUtils;
 import docking.event.mouse.GMouseListenerAdapter;
+import docking.help.HelpService;
 import docking.menu.DockingToolbarButton;
-import docking.util.*;
-import ghidra.generic.function.Callback;
+import docking.util.AnimationUtils;
+import docking.widgets.label.GDHtmlLabel;
 import ghidra.util.*;
 import ghidra.util.exception.AssertException;
 import ghidra.util.task.*;
+import utility.function.Callback;
 
 /**
  * Base class used for creating dialogs in Ghidra. Subclass this to create a dialog provider that has
  * all the gui elements to appear in the dialog, then use tool.showDialog() to display your dialog.
  */
-
 public class DialogComponentProvider
-		implements TaskListener, StatusListener, ActionContextProvider {
+		implements ActionContextProvider, StatusListener, TaskListener {
 
 	private static final Color WARNING_COLOR = new Color(0xff9900);
 
@@ -71,7 +74,7 @@ public class DialogComponentProvider
 	private TaskScheduler taskScheduler;
 	private TaskMonitorComponent taskMonitorComponent;
 
-	private static KeyStroke escKeyStroke = KeyStroke.getKeyStroke(KeyEvent.VK_ESCAPE, 0);
+	private static final KeyStroke ESC_KEYSTROKE = KeyStroke.getKeyStroke(KeyEvent.VK_ESCAPE, 0);
 
 	private CardLayout progressCardLayout;
 	private JButton defaultButton;
@@ -179,7 +182,7 @@ public class DialogComponentProvider
 			}
 		};
 
-		KeyBindingUtils.registerAction(rootPanel, escKeyStroke, escAction,
+		KeyBindingUtils.registerAction(rootPanel, ESC_KEYSTROKE, escAction,
 			JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT);
 	}
 
@@ -489,7 +492,7 @@ public class DialogComponentProvider
 	 */
 	protected void setApplyToolTip(String tooltip) {
 		if (applyButton != null) {
-			ToolTipManager.setToolTipText(applyButton, tooltip);
+			applyButton.setToolTipText(tooltip);
 		}
 	}
 
@@ -505,7 +508,7 @@ public class DialogComponentProvider
 	 */
 	protected void setOkToolTip(String tooltip) {
 		if (okButton != null) {
-			ToolTipManager.setToolTipText(okButton, tooltip);
+			okButton.setToolTipText(tooltip);
 		}
 	}
 
@@ -515,7 +518,7 @@ public class DialogComponentProvider
 	 */
 	protected void setCancelToolTip(String tooltip) {
 		if (cancelButton != null) {
-			ToolTipManager.setToolTipText(cancelButton, tooltip);
+			cancelButton.setToolTipText(tooltip);
 		}
 	}
 
@@ -531,7 +534,7 @@ public class DialogComponentProvider
 	 */
 	protected void setDismissToolTip(String tooltip) {
 		if (dismissButton != null) {
-			ToolTipManager.setToolTipText(dismissButton, tooltip);
+			dismissButton.setToolTipText(tooltip);
 		}
 	}
 
@@ -752,14 +755,16 @@ public class DialogComponentProvider
 	}
 
 	private void showProgressBar(String localTitle, boolean hasProgress, boolean canCancel) {
+
+		if (!isVisible()) {
+			// It doesn't make any sense to show the task monitor when the dialog is not 
+			// visible, so show the dialog
+			DockingWindowManager.showDialog(getParent(), this);
+		}
+
 		taskMonitorComponent.setTaskName(localTitle);
 		taskMonitorComponent.showProgress(hasProgress);
-		if (canCancel) {
-			taskMonitorComponent.showCancelButton(true);
-		}
-		else {
-			taskMonitorComponent.showCancelButton(false);
-		}
+		taskMonitorComponent.setCancelButtonVisibility(canCancel);
 		progressCardLayout.show(statusProgPanel, PROGRESS);
 		rootPanel.validate();
 	}
@@ -784,10 +789,10 @@ public class DialogComponentProvider
 			messageWidth = fm.stringWidth(text);
 		}
 		if (messageWidth > statusLabel.getWidth()) {
-			ToolTipManager.setToolTipText(statusLabel, text);
+			statusLabel.setToolTipText(text);
 		}
 		else {
-			ToolTipManager.setToolTipText(statusLabel, null);
+			statusLabel.setToolTipText(null);
 		}
 	}
 
@@ -803,7 +808,8 @@ public class DialogComponentProvider
 	}
 
 	/**
-	 * returns the current status in the dialogs status line=
+	 * Returns the current status in the dialogs status line
+	 * 
 	 * @return the status text
 	 */
 	public String getStatusText() {
@@ -889,7 +895,7 @@ public class DialogComponentProvider
 
 	private JPanel buildStatusPanel() {
 		JPanel panel = new JPanel(new BorderLayout());
-		statusLabel = new JLabel(" ");
+		statusLabel = new GDHtmlLabel(" ");
 		statusLabel.setName("statusLabel");
 		statusLabel.setHorizontalAlignment(SwingConstants.CENTER);
 		statusLabel.setForeground(Color.blue);
@@ -985,6 +991,15 @@ public class DialogComponentProvider
 		DockingWindowManager.setHelpLocation(rootPanel, helpLocation);
 	}
 
+	/**
+	 * Returns the help location for this dialog
+	 * @return the help location
+	 */
+	public HelpLocation getHelpLocatdion() {
+		HelpService helpService = DockingWindowManager.getHelpService();
+		return helpService.getHelpLocation(rootPanel);
+	}
+
 	/**
 	 * Sets the button to make "Default" when the dialog is shown.  If no default button is
 	 * desired, then pass <tt>null</tt> as the <tt>button</tt> value.
@@ -1056,6 +1071,13 @@ public class DialogComponentProvider
 		return dialog;
 	}
 
+	private Component getParent() {
+		if (dialog == null) {
+			return null;
+		}
+		return dialog.getParent();
+	}
+
 	public boolean isVisible() {
 		return ((dialog != null) && dialog.isVisible());
 	}
@@ -1115,7 +1137,23 @@ public class DialogComponentProvider
 	 */
 	@Override
 	public ActionContext getActionContext(MouseEvent event) {
-		return new ActionContext(null, null);
+
+		Component c = getComponent();
+		KeyboardFocusManager kfm = KeyboardFocusManager.getCurrentKeyboardFocusManager();
+		Component focusedComponent = kfm.getFocusOwner();
+		if (focusedComponent != null && SwingUtilities.isDescendingFrom(focusedComponent, c)) {
+			c = focusedComponent;
+		}
+
+		if (event == null) {
+			return new ActionContext(null, c);
+		}
+
+		Component sourceComponent = event.getComponent();
+		if (sourceComponent != null) {
+			c = sourceComponent;
+		}
+		return new ActionContext(null, c).setSourceObject(event.getSource());
 	}
 
 	/**
@@ -1356,5 +1394,4 @@ public class DialogComponentProvider
 		}
 
 	}
-
 }
