@@ -16,6 +16,7 @@
 package ghidra.app.decompiler.component;
 
 import ghidra.program.model.address.Address;
+import ghidra.program.model.listing.Function;
 import ghidra.program.util.ProgramLocation;
 import ghidra.program.util.ProgramSelection;
 import ghidra.util.bean.field.AnnotatedTextFieldElement;
@@ -42,4 +43,5 @@ public interface DecompilerCallbackHandler {
 
 	void exportLocation();
 
+	void goToFunction(Function function, boolean newWindow);
 }
