@@ -1,6 +1,5 @@
 /* ###
  * IP: GHIDRA
- * REVIEWED: YES
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,19 +15,40 @@
  */
 package ghidra.app.merge.listing;
 
-import ghidra.app.merge.util.ConflictUtility;
-import ghidra.util.datastruct.LongArrayList;
-import ghidra.util.layout.MaximizeSpecificColumnGridLayout;
+import java.awt.BorderLayout;
+import java.awt.Color;
+import java.awt.Component;
+import java.awt.Font;
+import java.awt.FontMetrics;
+import java.awt.Insets;
+import java.awt.event.ComponentEvent;
+import java.awt.event.ComponentListener;
+import java.awt.event.ItemEvent;
+import java.awt.event.ItemListener;
+import java.util.ArrayList;
+import java.util.Iterator;
+import java.util.ListIterator;
 
-import java.awt.*;
-import java.awt.event.*;
-import java.util.*;
-
-import javax.swing.*;
+import javax.swing.BorderFactory;
+import javax.swing.ButtonGroup;
+import javax.swing.JCheckBox;
+import javax.swing.JComponent;
+import javax.swing.JPanel;
+import javax.swing.JRadioButton;
+import javax.swing.SwingConstants;
 import javax.swing.border.Border;
 import javax.swing.border.TitledBorder;
 import javax.swing.event.ChangeListener;
 
+import docking.widgets.button.GRadioButton;
+import docking.widgets.checkbox.GCheckBox;
+import docking.widgets.label.GDHtmlLabel;
+import docking.widgets.label.GDLabel;
+import ghidra.app.merge.util.ConflictUtility;
+import ghidra.util.HTMLUtilities;
+import ghidra.util.datastruct.LongArrayList;
+import ghidra.util.layout.MaximizeSpecificColumnGridLayout;
+
 /**
  * <CODE>VerticalChoicesPanel</CODE> is a conflict panel for the Listing Merge.
  * It lays out rows of information vertically in a table format. 
@@ -51,7 +71,7 @@ public class VerticalChoicesPanel extends ConflictPanel {
 	final static int RADIO_BUTTON = 2;
 	final static int CHECK_BOX = 3;
 
-	private JLabel headerLabel;
+	private GDHtmlLabel headerLabel;
 	private JPanel rowPanel;
 	private ArrayList<ArrayList<JComponent>> rowComps;
 	private ArrayList<String[]> rows;
@@ -88,12 +108,12 @@ public class VerticalChoicesPanel extends ConflictPanel {
 		setBorder(BorderFactory.createTitledBorder("Resolve Conflict"));
 		setLayout(new BorderLayout());
 
-		headerLabel = new JLabel(" ");
+		headerLabel = new GDHtmlLabel(" ");
 		headerLabel.setHorizontalAlignment(SwingConstants.CENTER);
 		add(headerLabel, BorderLayout.NORTH);
 
-		rowComps = new ArrayList<ArrayList<JComponent>>();
-		rows = new ArrayList<String[]>();
+		rowComps = new ArrayList<>();
+		rows = new ArrayList<>();
 		rowTypes = new LongArrayList();
 		group = new ButtonGroup();
 		layout = new MaximizeSpecificColumnGridLayout(5, 5, columnCount);
@@ -102,31 +122,29 @@ public class VerticalChoicesPanel extends ConflictPanel {
 		add(rowPanel, BorderLayout.CENTER);
 		rowPanel.setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));
 
-		JRadioButton rb = new JRadioButton();
-		JCheckBox cb = new JCheckBox();
+		GRadioButton rb = new GRadioButton();
+		JCheckBox cb = new GCheckBox();
 		indent = Math.max(rb.getPreferredSize().width, cb.getPreferredSize().width);
 
 		defaultInsets = new Insets(DEFAULT_TOP, DEFAULT_LEFT, DEFAULT_BOTTOM, DEFAULT_RIGHT);
-		int labelHeight = (int) new JLabel("A").getPreferredSize().getHeight();
-		double buttonHeight =
-			new MyRadioButton("A", ListingMergeConstants.KEEP_LATEST).getPreferredSize().getHeight();
+		int labelHeight = (int) new GDLabel("A").getPreferredSize().getHeight();
+		double buttonHeight = new MyRadioButton("A",
+			ListingMergeConstants.KEEP_LATEST).getPreferredSize().getHeight();
 		int borderHeight;
 		borderHeight = (int) ((buttonHeight - labelHeight) / 2);
 		if (borderHeight < 0) {
 			borderHeight = 0;
 		}
-		textVsButtonInsets =
-			new Insets(DEFAULT_TOP + borderHeight, DEFAULT_LEFT, DEFAULT_BOTTOM + borderHeight,
-				DEFAULT_RIGHT);
+		textVsButtonInsets = new Insets(DEFAULT_TOP + borderHeight, DEFAULT_LEFT,
+			DEFAULT_BOTTOM + borderHeight, DEFAULT_RIGHT);
 		double checkBoxHeight =
 			new MyCheckBox("A", ListingMergeConstants.KEEP_LATEST).getPreferredSize().getHeight();
 		borderHeight = (int) ((checkBoxHeight - labelHeight) / 2);
 		if (borderHeight < 0) {
 			borderHeight = 0;
 		}
-		textVsCheckBoxInsets =
-			new Insets(DEFAULT_TOP + borderHeight, DEFAULT_LEFT, DEFAULT_BOTTOM + borderHeight,
-				DEFAULT_RIGHT);
+		textVsCheckBoxInsets = new Insets(DEFAULT_TOP + borderHeight, DEFAULT_LEFT,
+			DEFAULT_BOTTOM + borderHeight, DEFAULT_RIGHT);
 
 		add(createUseForAllCheckBox(), BorderLayout.SOUTH);
 	}
@@ -273,7 +291,7 @@ public class VerticalChoicesPanel extends ConflictPanel {
 		firstComp.addItemListener(itemListener);
 		setRowComponent(firstComp, row, 0, defaultInsets);
 		for (int i = 1; i < items.length; i++) {
-			JLabel newComp = new MyLabel(items[i]);
+			MyLabel newComp = new MyLabel(items[i]);
 			newComp.setName(getComponentName(row, i));
 			setRowComponent(newComp, row, i, textVsButtonInsets);
 		}
@@ -308,7 +326,7 @@ public class VerticalChoicesPanel extends ConflictPanel {
 		firstComp.addItemListener(itemListener);
 		setRowComponent(firstComp, row, 0, defaultInsets);
 		for (int i = 1; i < items.length; i++) {
-			JLabel newComp = new MyLabel(items[i]);
+			MyLabel newComp = new MyLabel(items[i]);
 			newComp.setName(getComponentName(row, i));
 			setRowComponent(newComp, row, i, textVsCheckBoxInsets);
 		}
@@ -453,8 +471,7 @@ public class VerticalChoicesPanel extends ConflictPanel {
 		return allChoicesAreResolved();
 	}
 
-	private class MyLabel extends JLabel {
-		private final static long serialVersionUID = 1;
+	private class MyLabel extends GDHtmlLabel {
 
 		/**
 		 * @param text the text of this label.
@@ -481,7 +498,9 @@ public class VerticalChoicesPanel extends ConflictPanel {
 						(displayedFont != null) ? getFontMetrics(displayedFont) : null;
 					int stringWidth =
 						(fontMetrics != null) ? fontMetrics.stringWidth(displayedText) : 0;
-					setToolTipText((stringWidth > displayedWidth) ? text : null);
+					setToolTipText(
+						(stringWidth > displayedWidth) ? "<html>" + HTMLUtilities.escapeHTML(text)
+								: null);
 				}
 
 				@Override
@@ -502,7 +521,7 @@ public class VerticalChoicesPanel extends ConflictPanel {
 		}
 	}
 
-	private class MyRadioButton extends JRadioButton {
+	private class MyRadioButton extends GRadioButton {
 		private final static long serialVersionUID = 1;
 		private int option;
 
@@ -558,7 +577,7 @@ public class VerticalChoicesPanel extends ConflictPanel {
 
 	}
 
-	private class MyCheckBox extends JCheckBox {
+	private class MyCheckBox extends GCheckBox {
 		private final static long serialVersionUID = 1;
 		private int option;
 
@@ -622,7 +641,8 @@ public class VerticalChoicesPanel extends ConflictPanel {
 			JComponent[] comps = getRowComponents(row);
 			for (int i = 0; i < comps.length; i++) {
 				JComponent component = comps[i];
-				if (component instanceof MyRadioButton && ((MyRadioButton) component).isSelected()) {
+				if (component instanceof MyRadioButton &&
+					((MyRadioButton) component).isSelected()) {
 					conflictOption |= ((MyRadioButton) component).option;
 				}
 				else if (component instanceof MyCheckBox && ((MyCheckBox) component).isSelected()) {
