@@ -25,6 +25,7 @@ import javax.swing.text.BadLocationException;
 
 import docking.EmptyBorderToggleButton;
 import docking.widgets.autocomplete.*;
+import docking.widgets.label.GDLabel;
 import docking.widgets.textfield.TextFieldLinker;
 import ghidra.GhidraApplicationLayout;
 import ghidra.GhidraLaunchable;
@@ -705,7 +706,7 @@ public class AssemblyDualTextField {
 			Box hbox = Box.createHorizontalBox();
 			dialog.add(hbox, BorderLayout.NORTH);
 
-			JLabel addrlabel = new JLabel(String.format(ADDR_FORMAT, curAddr));
+			JLabel addrlabel = new GDLabel(String.format(ADDR_FORMAT, curAddr));
 			hbox.add(addrlabel);
 
 			AssemblyDualTextField input = new AssemblyDualTextField();
