@@ -35,6 +35,7 @@ import docking.widgets.fieldpanel.FieldPanel;
 import docking.widgets.fieldpanel.Layout;
 import docking.widgets.fieldpanel.field.Field;
 import docking.widgets.fieldpanel.support.BackgroundColorModel;
+import docking.widgets.label.GDLabel;
 import ghidra.app.plugin.core.codebrowser.hover.ListingHoverService;
 import ghidra.app.plugin.core.functiongraph.FunctionGraphPlugin;
 import ghidra.app.plugin.core.functiongraph.graph.FGEdge;
@@ -197,13 +198,24 @@ public class ListingGraphComponentPanel extends AbstractGraphComponentPanel {
 
 	private void createListingPanelToolTipComponent() {
 		JPanel panel = new JPanel(new BorderLayout());
-		previewListingPanel =
-			new FGVertexListingPanel(controller, getFormatManager(true), program, addressSet);
+
+		FunctionGraphOptions options = controller.getFunctionGraphOptions();
+		boolean useFullSizeTooltip = options.useFullSizeTooltip();
+		previewListingPanel = new FGVertexListingPanel(controller,
+			getFormatManager(useFullSizeTooltip), program, addressSet);
 		previewListingPanel.setTextBackgroundColor(FGVertex.TOOLTIP_BACKGROUND_COLOR);
 		//            previewListingPanel.getFieldPanel().setSelectionMode( FieldPanel.NO_SELECTION );
 		previewListingPanel.getFieldPanel().setCursorOn(false);
 
-		tooltipTitleLabel = new JLabel();
+		// keep the tooltip window from getting too big; use an arbitrary, reasonable max
+		Dimension maxSize = new Dimension(700, 400);
+		previewListingPanel.setMaximumSize(maxSize);
+		Dimension preferredSize = previewListingPanel.getPreferredSize();
+		preferredSize.width = Math.min(maxSize.width, preferredSize.width);
+		preferredSize.height = Math.min(maxSize.height, preferredSize.height);
+		previewListingPanel.setPreferredSize(preferredSize);
+
+		tooltipTitleLabel = new GDLabel();
 		tooltipTitleLabel.setHorizontalAlignment(SwingConstants.LEADING);
 		tooltipTitleLabel.setBackground(FGVertex.TOOLTIP_BACKGROUND_COLOR);
 		tooltipTitleLabel.setOpaque(true);
@@ -238,6 +250,7 @@ public class ListingGraphComponentPanel extends AbstractGraphComponentPanel {
 		// make sure the title stays up-to-date with the symbol at the start address
 		title = createTitle();
 		genericHeader.setTitle(title);
+		previewListingPanel = null;
 	}
 
 	@Override
@@ -261,6 +274,11 @@ public class ListingGraphComponentPanel extends AbstractGraphComponentPanel {
 		return listingPanel.getTextBackgroundColor();
 	}
 
+	@Override
+	Color getSelectionColor() {
+		return fieldPanel.getSelectionColor();
+	}
+
 	private void createActions() {
 		String firstGroup = "group1";
 		String secondGroup = "group2";
@@ -487,7 +505,7 @@ public class ListingGraphComponentPanel extends AbstractGraphComponentPanel {
 		if (address == null) {
 			// This is an unusual case.   For now, do something reasonable.
 			String side = isDestinationVertex ? "end" : "start";
-			toolTipComponent = new JLabel("Unable to find address for edge " + side + ": " + edge);
+			toolTipComponent = new GDLabel("Unable to find address for edge " + side + ": " + edge);
 			toolTipComponent.setBorder(BorderFactory.createEmptyBorder(0, 10, 0, 10));
 			if (previewListingPanel != null) {
 				previewListingPanel = null;
