@@ -159,8 +159,14 @@ public class ElfHeader implements StructConverter, Writeable {
 			e_ehsize = reader.readNextShort();
 			e_phentsize = reader.readNextShort();
 			e_phnum = reader.readNextShort();
+			if (e_phnum < 0) {
+				e_phnum = 0; // protect against stripped program headers
+			}
 			e_shentsize = reader.readNextShort();
 			e_shnum = reader.readNextShort();
+			if (e_shnum < 0) {
+				e_shnum = 0; // protect against stripped section headers (have seen -1)
+			}
 			e_shstrndx = reader.readNextShort();
 		}
 		catch (IOException e) {
@@ -384,6 +390,10 @@ public class ElfHeader implements StructConverter, Writeable {
 						" linked to symbol table section " + symbolTableSection.getNameAsString() +
 						" affecting " + relocaBaseName);
 
+				if (section.getOffset() < 0) {
+					return;
+				}
+
 				relocationTableList.add(ElfRelocationTable.createElfRelocationTable(reader, this,
 					section, section.getOffset(), section.getAddress(), section.getSize(),
 					section.getEntrySize(), addendTypeReloc, symbolTable, sectionToBeRelocated));
@@ -447,6 +457,9 @@ public class ElfHeader implements StructConverter, Writeable {
 					Long.toHexString(relocTableAddr));
 				return;
 			}
+			if (relocTableLoadHeader.getOffset() < 0) {
+				return;
+			}
 
 			if (dynamicSymbolTable == null) {
 				Msg.warn(this, "Failed to process " + relocTableAddrType.name +
@@ -649,6 +662,9 @@ public class ElfHeader implements StructConverter, Writeable {
 			if (sectionHeaders[i].getType() == ElfSectionHeaderConstants.SHT_SYMTAB ||
 				sectionHeaders[i].getType() == ElfSectionHeaderConstants.SHT_DYNSYM) {
 				ElfSectionHeader symbolTableSectionHeader = sectionHeaders[i];
+				if (symbolTableSectionHeader.getOffset() < 0) {
+					continue;
+				}
 
 				ElfSectionHeader stringTableSectionHeader =
 					sectionHeaders[symbolTableSectionHeader.getLink()];
@@ -1537,13 +1553,24 @@ public class ElfHeader implements StructConverter, Writeable {
 	}
 
 	/**
-	 * Returns the relocation table associated to the specified section header.
-	 * Or, null if one does not exist.
+	 * Returns the relocation table associated to the specified section header,
+	 * or null if one does not exist.
+	 * @param relocSection section header corresponding to relocation table
 	 * @return the relocation table associated to the specified section header
 	 */
 	public ElfRelocationTable getRelocationTable(ElfSectionHeader relocSection) {
+		return getRelocationTableAtOffset(relocSection.getOffset());
+	}
+
+	/**
+	 * Returns the relocation table located at the specified fileOffset,
+	 * or null if one does not exist.
+	 * @param fileOffset file offset corresponding to start of relocation table
+	 * @return the relocation table located at the specified fileOffset or null
+	 */
+	public ElfRelocationTable getRelocationTableAtOffset(long fileOffset) {
 		for (int i = 0; i < relocationTables.length; i++) {
-			if (relocationTables[i].getFileOffset() == relocSection.getOffset()) {
+			if (relocationTables[i].getFileOffset() == fileOffset) {
 				return relocationTables[i];
 			}
 		}
