@@ -16,34 +16,38 @@
 package ghidra.app.util.opinion;
 
 import java.io.IOException;
-import java.io.InputStream;
+import java.math.BigInteger;
 import java.util.*;
 
 import generic.continues.GenericFactory;
 import generic.continues.RethrowContinuesFactory;
-import ghidra.app.util.MemoryBlockUtil;
+import ghidra.app.util.MemoryBlockUtils;
 import ghidra.app.util.Option;
-import ghidra.app.util.bin.*;
+import ghidra.app.util.bin.BinaryReader;
+import ghidra.app.util.bin.ByteProvider;
 import ghidra.app.util.bin.format.mz.DOSHeader;
 import ghidra.app.util.bin.format.pe.*;
 import ghidra.app.util.bin.format.pe.PortableExecutable.SectionLayout;
 import ghidra.app.util.bin.format.pe.debug.DebugCOFFSymbol;
 import ghidra.app.util.bin.format.pe.debug.DebugDirectoryParser;
-import ghidra.app.util.demangler.*;
-import ghidra.app.util.importer.*;
+import ghidra.app.util.importer.MessageLog;
+import ghidra.app.util.importer.MessageLogContinuesFactory;
 import ghidra.framework.model.DomainObject;
 import ghidra.framework.options.Options;
+import ghidra.program.database.mem.FileBytes;
 import ghidra.program.model.address.*;
 import ghidra.program.model.data.*;
+import ghidra.program.model.lang.Register;
+import ghidra.program.model.lang.RegisterValue;
 import ghidra.program.model.listing.*;
-import ghidra.program.model.mem.*;
+import ghidra.program.model.mem.Memory;
+import ghidra.program.model.mem.MemoryAccessException;
 import ghidra.program.model.reloc.RelocationTable;
 import ghidra.program.model.symbol.*;
 import ghidra.program.model.util.AddressSetPropertyMap;
 import ghidra.program.model.util.CodeUnitInsertionException;
 import ghidra.util.*;
-import ghidra.util.exception.DuplicateNameException;
-import ghidra.util.exception.InvalidInputException;
+import ghidra.util.exception.*;
 import ghidra.util.task.TaskMonitor;
 
 /**
@@ -92,8 +96,8 @@ public class PeLoader extends AbstractPeDebugLoader {
 
 	@Override
 	protected void load(ByteProvider provider, LoadSpec loadSpec, List<Option> options,
-			Program program, MemoryConflictHandler handler, TaskMonitor monitor, MessageLog log)
-			throws IOException {
+			Program program, TaskMonitor monitor, MessageLog log)
+			throws IOException, CancelledException {
 
 		if (monitor.isCancelled()) {
 			return;
@@ -111,10 +115,10 @@ public class PeLoader extends AbstractPeDebugLoader {
 		FileHeader fileHeader = ntHeader.getFileHeader();
 
 		monitor.setMessage("Completing PE header parsing...");
-
+		FileBytes fileBytes = MemoryBlockUtils.createFileBytes(program, provider, monitor);
 		try {
-			Map<Integer, Address> sectionNumberToAddress =
-				processMemoryBlocks(pe, program, handler, monitor, log);
+			Map<SectionHeader, Address> sectionToAddress =
+				processMemoryBlocks(pe, program, fileBytes, monitor, log);
 
 			monitor.setCancelEnabled(false);
 			optionalHeader.processDataDirectories(monitor);
@@ -132,13 +136,15 @@ public class PeLoader extends AbstractPeDebugLoader {
 				}
 			}
 
+			setProcessorContext(fileHeader, program, monitor, log);
+
 			processExports(optionalHeader, program, monitor, log);
 			processImports(optionalHeader, program, monitor, log);
 			processRelocations(optionalHeader, program, monitor, log);
-			processDebug(optionalHeader, sectionNumberToAddress, program, monitor);
+			processDebug(optionalHeader, fileHeader, sectionToAddress, program, monitor);
 			processProperties(optionalHeader, program, monitor);
 			processComments(program.getListing(), monitor);
-			processSymbols(fileHeader, sectionNumberToAddress, program, monitor, log);
+			processSymbols(fileHeader, sectionToAddress, program, monitor, log);
 
 			processEntryPoints(ntHeader, program, monitor);
 			String compiler = CompilerOpinion.getOpinion(pe, provider).toString();
@@ -160,7 +166,7 @@ public class PeLoader extends AbstractPeDebugLoader {
 		catch (MemoryAccessException e) {
 			throw new IOException(e);
 		}
-		monitor.setMessage(program.getName() + ": done!");
+		monitor.setMessage("[" + program.getName() + "]: done!");
 	}
 
 	@Override
@@ -176,7 +182,7 @@ public class PeLoader extends AbstractPeDebugLoader {
 	}
 
 	@Override
-	public String validateOptions(ByteProvider provider, LoadSpec loadSpec, List<Option> options) {
+	public String validateOptions(ByteProvider provider, LoadSpec loadSpec, List<Option> options, Program program) {
 		if (options != null) {
 			for (Option option : options) {
 				String name = option.getName();
@@ -187,7 +193,7 @@ public class PeLoader extends AbstractPeDebugLoader {
 				}
 			}
 		}
-		return super.validateOptions(provider, loadSpec, options);
+		return super.validateOptions(provider, loadSpec, options, program);
 	}
 
 	@Override
@@ -256,12 +262,12 @@ public class PeLoader extends AbstractPeDebugLoader {
 		}
 	}
 
-	private void processSymbols(FileHeader fileHeader, Map<Integer, Address> sectionNumberToAddress,
+	private void processSymbols(FileHeader fileHeader, Map<SectionHeader, Address> sectionToAddress,
 			Program program, TaskMonitor monitor, MessageLog log) {
 		List<DebugCOFFSymbol> symbols = fileHeader.getSymbols();
 		int errorCount = 0;
 		for (DebugCOFFSymbol symbol : symbols) {
-			if (!processDebugCoffSymbol(symbol, sectionNumberToAddress, program, monitor)) {
+			if (!processDebugCoffSymbol(symbol, fileHeader, sectionToAddress, program, monitor)) {
 				++errorCount;
 			}
 		}
@@ -289,7 +295,7 @@ public class PeLoader extends AbstractPeDebugLoader {
 		if (monitor.isCancelled()) {
 			return;
 		}
-		monitor.setMessage(prog.getName() + ": processing relocation tables...");
+		monitor.setMessage("[" + prog.getName() + "]: processing relocation tables...");
 
 		DataDirectory[] dataDirectories = optionalHeader.getDataDirectories();
 		if (dataDirectories.length <= OptionalHeader.IMAGE_DIRECTORY_ENTRY_BASERELOC) {
@@ -375,7 +381,7 @@ public class PeLoader extends AbstractPeDebugLoader {
 		if (monitor.isCancelled()) {
 			return;
 		}
-		monitor.setMessage(program.getName() + ": processing imports...");
+		monitor.setMessage("[" + program.getName() + "]: processing imports...");
 
 		DataDirectory[] dataDirectories = optionalHeader.getDataDirectories();
 		if (dataDirectories.length <= OptionalHeader.IMAGE_DIRECTORY_ENTRY_IMPORT) {
@@ -464,13 +470,34 @@ public class PeLoader extends AbstractPeDebugLoader {
 		}
 	}
 
+	private void setProcessorContext(FileHeader fileHeader, Program program, TaskMonitor monitor,
+			MessageLog log) {
+
+		try {
+			String machineName = fileHeader.getMachineName();
+			if ("450".equals(machineName) || "452".equals(machineName)) {
+				Register tmodeReg = program.getProgramContext().getRegister("TMode");
+				if (tmodeReg == null) {
+					return;
+				}
+				RegisterValue thumbMode = new RegisterValue(tmodeReg, BigInteger.ONE);
+				AddressSpace space = program.getAddressFactory().getDefaultAddressSpace();
+				program.getProgramContext().setRegisterValue(space.getMinAddress(),
+					space.getMaxAddress(), thumbMode);
+			}
+		}
+		catch (ContextChangeException e) {
+			throw new AssertException("instructions should not exist");
+		}
+	}
+
 	private void processExports(OptionalHeader optionalHeader, Program program, TaskMonitor monitor,
 			MessageLog log) {
 
 		if (monitor.isCancelled()) {
 			return;
 		}
-		monitor.setMessage(program.getName() + ": processing exports...");
+		monitor.setMessage("[" + program.getName() + "]: processing exports...");
 
 		DataDirectory[] dataDirectories = optionalHeader.getDataDirectories();
 		if (dataDirectories.length <= OptionalHeader.IMAGE_DIRECTORY_ENTRY_EXPORT) {
@@ -508,21 +535,6 @@ public class PeLoader extends AbstractPeDebugLoader {
 				// Don't create invalid symbol
 			}
 
-			DemangledObject demangledObj = null;
-			try {
-				demangledObj = DemanglerUtil.demangle(program, name);
-			}
-			catch (Exception e) {
-				//log.appendMsg("Unable to demangle: "+name);
-			}
-			if (demangledObj != null) {
-				String comment = demangledObj.getSignature(true);
-				if (hasComment(CodeUnit.PLATE_COMMENT, address)) {
-					comment = "\n" + comment;
-				}
-				setComment(CodeUnit.PLATE_COMMENT, address, comment);
-			}
-
 			try {
 				symTable.createLabel(address, SymbolUtilities.ORDINAL_PREFIX + export.getOrdinal(),
 					SourceType.IMPORTED);
@@ -574,127 +586,78 @@ public class PeLoader extends AbstractPeDebugLoader {
 					// Nothing to do...just continue on
 				}
 			}
-
-			//if this export is not in an executable section,
-			//then it is a DATA export.
-			//see if it is a pointer, otherwise make it an undefined1
-			MemoryBlock block = memory.getBlock(address);
-			if (block != null && !block.isExecute()) {
-				try {
-					if (demangledObj instanceof DemangledVariable) {
-						DemangledVariable demangledVar = (DemangledVariable) demangledObj;
-						DemangledDataType ddt = demangledVar.getDataType();
-						DataType dt =
-							ddt == null ? null : ddt.getDataType(program.getDataTypeManager());
-						if (dt != null && dt.getLength() > 0) {
-							listing.createData(address, dt);
-						}
-						else {
-							listing.createData(address, new Undefined1DataType());
-						}
-					}
-					else {
-						listing.createData(address, StructConverter.POINTER,
-							address.getPointerSize());
-						Data data = listing.getDataAt(address);
-						Address ptr = data.getAddress(0);
-						if (ptr == null || !memory.contains(ptr)) {
-							listing.clearCodeUnits(data.getMinAddress(), data.getMaxAddress(),
-								false);
-							listing.createData(address, new Undefined1DataType());
-						}
-					}
-				}
-				catch (DataTypeConflictException | CodeUnitInsertionException e) {
-					// Nothing to do...just continue on
-				}
-			}
 		}
 	}
 
-	private Map<Integer, Address> processMemoryBlocks(PortableExecutable pe, Program prog,
-			MemoryConflictHandler handler, TaskMonitor monitor, MessageLog log)
+	private Map<SectionHeader, Address> processMemoryBlocks(PortableExecutable pe, Program prog,
+			FileBytes fileBytes, TaskMonitor monitor, MessageLog log)
 			throws AddressOverflowException, IOException {
 
 		AddressFactory af = prog.getAddressFactory();
 		AddressSpace space = af.getDefaultAddressSpace();
-		Map<Integer, Address> sectionNumberToAddress = new HashMap<>();
+		Map<SectionHeader, Address> sectionToAddress = new HashMap<>();
 
 		if (monitor.isCancelled()) {
-			return sectionNumberToAddress;
+			return sectionToAddress;
 		}
-		monitor.setMessage(prog.getName() + ": processing memory blocks...");
+		monitor.setMessage("[" + prog.getName() + "]: processing memory blocks...");
 
 		NTHeader ntHeader = pe.getNTHeader();
 		FileHeader fileHeader = ntHeader.getFileHeader();
 		OptionalHeader optionalHeader = ntHeader.getOptionalHeader();
 
-		MemoryBlockUtil mbu = new MemoryBlockUtil(prog, handler);
-
 		SectionHeader[] sections = fileHeader.getSectionHeaders();
 		if (sections.length == 0) {
 			Msg.warn(this, "No sections found");
 		}
 
 		// Header block
-		try {
-			int virtualSize = getVirtualSize(pe, sections, space);
-			long addr = optionalHeader.getImageBase();
-			Address address = space.getAddress(addr);
+		int virtualSize = (int) Math.min(getVirtualSize(pe, sections, space), fileBytes.getSize());
+		long addr = optionalHeader.getImageBase();
+		Address address = space.getAddress(addr);
 
-			boolean r = true;
-			boolean w = false;
-			boolean x = false;
-
-			try (InputStream dataStream = fileHeader.getDataStream()) {
-				mbu.createInitializedBlock(HEADERS, address, dataStream, virtualSize, "", "", r, w,
-					x, monitor);
-			}
-		}
-		finally {
-			log.appendMsg(mbu.getMessages());
-			mbu.dispose();
-			mbu = null;
-		}
-
-		mbu = new MemoryBlockUtil(prog, handler);
+		boolean r = true;
+		boolean w = false;
+		boolean x = false;
+		MemoryBlockUtils.createInitializedBlock(prog, false, HEADERS, address, fileBytes, 0,
+			virtualSize, "", "", r, w, x, log);
 
 		// Section blocks
 		try {
 			for (int i = 0; i < sections.length; ++i) {
 				if (monitor.isCancelled()) {
-					return sectionNumberToAddress;
+					return sectionToAddress;
 				}
 
-				long addr = sections[i].getVirtualAddress() + optionalHeader.getImageBase();
+				addr = sections[i].getVirtualAddress() + optionalHeader.getImageBase();
 
-				Address address = space.getAddress(addr);
+				address = space.getAddress(addr);
 
-				boolean r = ((sections[i].getCharacteristics() &
+				r = ((sections[i].getCharacteristics() &
 					SectionFlags.IMAGE_SCN_MEM_READ.getMask()) != 0x0);
-				boolean w = ((sections[i].getCharacteristics() &
+				w = ((sections[i].getCharacteristics() &
 					SectionFlags.IMAGE_SCN_MEM_WRITE.getMask()) != 0x0);
-				boolean x = ((sections[i].getCharacteristics() &
+				x = ((sections[i].getCharacteristics() &
 					SectionFlags.IMAGE_SCN_MEM_EXECUTE.getMask()) != 0x0);
 
 				int rawDataSize = sections[i].getSizeOfRawData();
-				int virtualSize = sections[i].getVirtualSize();
+				virtualSize = sections[i].getVirtualSize();
 				if (rawDataSize != 0) {
-					try (InputStream dataStream = sections[i].getDataStream()) {
-						int dataSize =
-							((rawDataSize > virtualSize && virtualSize > 0) || rawDataSize < 0)
-									? virtualSize : rawDataSize;
-						if (ntHeader.checkRVA(dataSize) ||
-							(0 < dataSize && dataSize < pe.getFileLength())) {
-							if (!ntHeader.checkRVA(dataSize)) {
-								Msg.warn(this, "OptionalHeader.SizeOfImage < size of " +
-									sections[i].getName() + " section");
-							}
-							mbu.createInitializedBlock(sections[i].getReadableName(), address,
-								dataStream, dataSize, "", "", r, w, x, monitor);
-
-							sectionNumberToAddress.put(i + 1, address);
+					int dataSize =
+						((rawDataSize > virtualSize && virtualSize > 0) || rawDataSize < 0)
+								? virtualSize
+								: rawDataSize;
+					if (ntHeader.checkRVA(dataSize) ||
+						(0 < dataSize && dataSize < pe.getFileLength())) {
+						if (!ntHeader.checkRVA(dataSize)) {
+							Msg.warn(this, "OptionalHeader.SizeOfImage < size of " +
+								sections[i].getName() + " section");
 						}
+						long offset = sections[i].getPointerToRawData();
+						MemoryBlockUtils.createInitializedBlock(prog, false,
+							sections[i].getReadableName(), address, fileBytes, offset, dataSize, "",
+							"", r, w, x, log);
+						sectionToAddress.put(sections[i], address);
 					}
 					if (rawDataSize == virtualSize) {
 						continue;
@@ -721,9 +684,9 @@ public class PeLoader extends AbstractPeDebugLoader {
 				else {
 					int dataSize = (virtualSize > 0 || rawDataSize < 0) ? virtualSize : 0;
 					if (dataSize > 0) {
-						mbu.createUninitializedBlock(false, sections[i].getReadableName(), address,
-							dataSize, "", "", r, w, x);
-						sectionNumberToAddress.put(i + 1, address);
+						MemoryBlockUtils.createUninitializedBlock(prog, false,
+							sections[i].getReadableName(), address, dataSize, "", "", r, w, x, log);
+						sectionToAddress.put(sections[i], address);
 					}
 				}
 
@@ -735,13 +698,8 @@ public class PeLoader extends AbstractPeDebugLoader {
 			}
 			Msg.warn(this, "Section header processing aborted");
 		}
-		finally {
-			log.appendMsg(mbu.getMessages());
-			mbu.dispose();
-			mbu = null;
-		}
 
-		return sectionNumberToAddress;
+		return sectionToAddress;
 	}
 
 	private int getVirtualSize(PortableExecutable pe, SectionHeader[] sections,
@@ -774,7 +732,7 @@ public class PeLoader extends AbstractPeDebugLoader {
 		if (monitor.isCancelled()) {
 			return;
 		}
-		monitor.setMessage(prog.getName() + ": processing entry points...");
+		monitor.setMessage("[" + prog.getName() + "]: processing entry points...");
 
 		OptionalHeader optionalHeader = ntHeader.getOptionalHeader();
 		AddressFactory af = prog.getAddressFactory();
@@ -803,12 +761,12 @@ public class PeLoader extends AbstractPeDebugLoader {
 		symTable.addExternalEntryPoint(entryAddr);
 	}
 
-	private void processDebug(OptionalHeader optionalHeader,
-			Map<Integer, Address> sectionNumberToAddress, Program program, TaskMonitor monitor) {
+	private void processDebug(OptionalHeader optionalHeader, FileHeader fileHeader,
+			Map<SectionHeader, Address> sectionToAddress, Program program, TaskMonitor monitor) {
 		if (monitor.isCancelled()) {
 			return;
 		}
-		monitor.setMessage(program.getName() + ": processing debug information...");
+		monitor.setMessage("[" + program.getName() + "]: processing debug information...");
 
 		DataDirectory[] dataDirectories = optionalHeader.getDataDirectories();
 		if (dataDirectories.length <= OptionalHeader.IMAGE_DIRECTORY_ENTRY_DEBUG) {
@@ -826,7 +784,7 @@ public class PeLoader extends AbstractPeDebugLoader {
 			return;
 		}
 
-		processDebug(parser, sectionNumberToAddress, program, monitor);
+		processDebug(parser, fileHeader, sectionToAddress, program, monitor);
 	}
 
 	@Override
