@@ -17,8 +17,7 @@ package ghidra.feature.vt.gui.plugin;
 
 import java.awt.Component;
 import java.io.*;
-import java.util.ArrayList;
-import java.util.List;
+import java.util.*;
 
 import javax.swing.KeyStroke;
 
@@ -27,6 +26,8 @@ import org.jdom.output.XMLOutputter;
 
 import docking.ActionContext;
 import docking.action.*;
+import docking.tool.ToolConstants;
+import docking.tool.util.DockingToolConstants;
 import docking.widgets.OptionDialog;
 import docking.widgets.fieldpanel.FieldPanel;
 import docking.widgets.fieldpanel.support.FieldSelection;
@@ -48,7 +49,8 @@ import ghidra.framework.ToolUtils;
 import ghidra.framework.model.*;
 import ghidra.framework.options.*;
 import ghidra.framework.plugintool.*;
-import ghidra.framework.plugintool.util.*;
+import ghidra.framework.plugintool.util.PluginException;
+import ghidra.framework.plugintool.util.PluginStatus;
 import ghidra.framework.project.tool.GhidraTool;
 import ghidra.program.model.address.*;
 import ghidra.program.model.listing.*;
@@ -121,7 +123,7 @@ public class VTSubToolManager implements VTControllerListener, OptionsChangeList
 	}
 
 	private void resetTool(String toolName) {
-		String toolFileName = toolName + ".tool";
+		String toolFileName = toolName + ToolUtils.TOOL_EXTENSION;
 		File toolFile = new File(ToolUtils.getApplicationToolDirPath(), toolFileName);
 		if (toolFile.exists()) {
 			toolFile.delete();
@@ -153,17 +155,17 @@ public class VTSubToolManager implements VTControllerListener, OptionsChangeList
 		catch (PluginException e) {
 			Msg.error(this, "Failed to create subordinate tool: " + toolName);
 		}
+
 		newTool.setToolName(toolName);
-		newTool.removeAction(newTool.getDockingActionsByFullActionName("Save Tool (Tool)").get(0));
-		newTool.removeAction(
-			newTool.getDockingActionsByFullActionName("Save Tool As (Tool)").get(0));
-		// newTool.removeAction(newTool.getDockableActionsByFullActionName("Export
-		// Tool (Tool)").get(0));
+
+		DockingActionIf save = getToolAction(newTool, "Save Tool");
+		newTool.removeAction(save);
+
 		createMarkupActions(newTool);
 
 		newTool.setConfigChanged(false);
 
-		ToolOptions options = newTool.getOptions(ToolConstants.KEY_BINDINGS);
+		ToolOptions options = newTool.getOptions(DockingToolConstants.KEY_BINDINGS);
 		options.addOptionsChangeListener(this);
 
 		// custom VT actions
@@ -172,6 +174,16 @@ public class VTSubToolManager implements VTControllerListener, OptionsChangeList
 		return newTool;
 	}
 
+	private DockingActionIf getToolAction(Tool tool, String actionName) {
+		Set<DockingActionIf> actions = tool.getDockingActionsByOwnerName(ToolConstants.TOOL_OWNER);
+		for (DockingActionIf action : actions) {
+			if (action.getName().equals(actionName)) {
+				return action;
+			}
+		}
+		throw new IllegalArgumentException("Unable to find Tool action '" + actionName + "'");
+	}
+
 	@Override
 	public void optionsChanged(ToolOptions options, String optionName, Object oldValue,
 			Object newValue) {
