@@ -394,7 +394,8 @@ public class FileSystemService {
 	 * @return {@link FSRL} pointing to the same file, never null
 	 */
 	public FSRL getLocalFSRL(File f) {
-		return localFS.getFSRL().withPath(FilenameUtils.separatorsToUnix(f.getPath()));
+		return localFS.getFSRL().withPath(
+			FSUtilities.appendPath("/", FilenameUtils.separatorsToUnix(f.getPath())));
 	}
 
 	/**
@@ -447,15 +448,16 @@ public class FileSystemService {
 	 * lambda will be called and it will be responsible for returning an {@link InputStream}
 	 * which has the derived contents, which will be added to the file cache for next time.
 	 * <p>
-	 * @param fsrl {@link FSRL} of the source file that this derived file is based on.
-	 * @param derivedName a unique string identifying the derived file.
+	 * @param fsrl {@link FSRL} of the source (or container) file that this derived file is based on
+	 * @param derivedName a unique string identifying the derived file inside the source (or container) file
 	 * @param producer a {@link DerivedFileProducer callback or lambda} that returns an
 	 * {@link InputStream} that will be streamed into a file and placed into the file cache.
+	 * Example: <pre>(file) -> { return new XYZDecryptorInputStream(file); }</pre>
 	 * @param monitor {@link TaskMonitor} that will be monitor for cancel requests and updated
-	 * with file io progress.
-	 * @return {@link FileCacheEntry} with file and md5 fields.
-	 * @throws CancelledException if the user cancels.
-	 * @throws IOException if there was an io error.
+	 * with file io progress
+	 * @return {@link FileCacheEntry} with file and md5 fields
+	 * @throws CancelledException if the user cancels
+	 * @throws IOException if there was an io error
 	 */
 	public FileCacheEntry getDerivedFile(FSRL fsrl, String derivedName,
 			DerivedFileProducer producer, TaskMonitor monitor)
@@ -466,19 +468,16 @@ public class FileSystemService {
 		// case should be okay as the only bad result will be extra
 		// work being performed recreating the contents of the same derived file a second
 		// time.
-		FileCacheEntry srcCFI = getCacheFile(fsrl, monitor);
-		String derivedMD5 = fileCacheNameIndex.get(srcCFI.md5, derivedName);
+		FileCacheEntry cacheEntry = getCacheFile(fsrl, monitor);
+		String derivedMD5 = fileCacheNameIndex.get(cacheEntry.md5, derivedName);
 		FileCacheEntry derivedFile = (derivedMD5 != null) ? fileCache.getFile(derivedMD5) : null;
 		if (derivedFile == null) {
 			monitor.setMessage(derivedName + " " + fsrl.getName());
-			try (InputStream is = producer.produceDerivedStream(srcCFI.file)) {
+			try (InputStream is = producer.produceDerivedStream(cacheEntry.file)) {
 				derivedFile = fileCache.addStream(is, monitor);
-				fileCacheNameIndex.add(srcCFI.md5, derivedName, derivedFile.md5);
+				fileCacheNameIndex.add(cacheEntry.md5, derivedName, derivedFile.md5);
 			}
 		}
-		else {
-			Msg.info(null, "Found derived file in cache: " + fsrl + ", " + derivedName);
-		}
 		return derivedFile;
 	}
 
@@ -491,15 +490,15 @@ public class FileSystemService {
 	 * lambda will be called and it will be responsible for producing and writing the derived
 	 * file's bytes to a {@link OutputStream}, which will be added to the file cache for next time.
 	 * <p>
-	 * @param fsrl {@link FSRL} of the source file that this derived file is based on.
-	 * @param derivedName a unique string identifying the derived file.
+	 * @param fsrl {@link FSRL} of the source (or container) file that this derived file is based on
+	 * @param derivedName a unique string identifying the derived file inside the source (or container) file
 	 * @param pusher a {@link DerivedFilePushProducer callback or lambda} that recieves a {@link OutputStream}.
 	 * Example: <pre>(os) -> { ...write to outputstream os here...; }</pre>
 	 * @param monitor {@link TaskMonitor} that will be monitor for cancel requests and updated
-	 * with file io progress.
-	 * @return {@link FileCacheEntry} with file and md5 fields.
-	 * @throws CancelledException if the user cancels.
-	 * @throws IOException if there was an io error.
+	 * with file io progress
+	 * @return {@link FileCacheEntry} with file and md5 fields
+	 * @throws CancelledException if the user cancels
+	 * @throws IOException if there was an io error
 	 */
 	public FileCacheEntry getDerivedFilePush(FSRL fsrl, String derivedName,
 			DerivedFilePushProducer pusher, TaskMonitor monitor)
@@ -510,20 +509,34 @@ public class FileSystemService {
 		// case should be okay as the only bad result will be extra
 		// work being performed recreating the contents of the same derived file a second
 		// time.
-		FileCacheEntry srcCFI = getCacheFile(fsrl, monitor);
-		String derivedMD5 = fileCacheNameIndex.get(srcCFI.md5, derivedName);
+		FileCacheEntry cacheEntry = getCacheFile(fsrl, monitor);
+		String derivedMD5 = fileCacheNameIndex.get(cacheEntry.md5, derivedName);
 		FileCacheEntry derivedFile = (derivedMD5 != null) ? fileCache.getFile(derivedMD5) : null;
 		if (derivedFile == null) {
-			monitor.setMessage(fsrl.getName() + " " + derivedName);
+			monitor.setMessage("Caching " + fsrl.getName() + " " + derivedName);
 			derivedFile = fileCache.pushStream(pusher, monitor);
-			fileCacheNameIndex.add(srcCFI.md5, derivedName, derivedFile.md5);
-		}
-		else {
-			Msg.info(null, "Found derived file in cache: " + fsrl + ", " + derivedName);
+			fileCacheNameIndex.add(cacheEntry.md5, derivedName, derivedFile.md5);
 		}
 		return derivedFile;
 	}
 
+	/**
+	 * Returns true if the specified derived file exists in the file cache.
+	 * 
+	 * @param fsrl {@link FSRL} of the container
+	 * @param derivedName name of the derived file inside of the container
+	 * @param monitor {@link TaskMonitor}
+	 * @return boolean true if file exists at time of query, false if file is not in cache
+	 * @throws CancelledException if user cancels
+	 * @throws IOException if other IO error
+	 */
+	public boolean hasDerivedFile(FSRL fsrl, String derivedName, TaskMonitor monitor)
+			throws CancelledException, IOException {
+		FileCacheEntry cacheEntry = getCacheFile(fsrl, monitor);
+		String derivedMD5 = fileCacheNameIndex.get(cacheEntry.md5, derivedName);
+		return derivedMD5 != null;
+	}
+
 	/**
 	 * Returns true if the container file probably holds one of the currently supported
 	 * filesystem types.
@@ -686,6 +699,34 @@ public class FileSystemService {
 		return fsClass.cast(fs);
 	}
 
+	/**
+	 * Open the file system contained at the specified location.
+	 * <p>
+	 * The newly constructed / mounted file system is not managed by this FileSystemService
+	 * or controlled with {@link FileSystemRef}s.
+	 * <p>
+	 * The caller is responsible for closing the resultant file system instance when it is
+	 * no longer needed.
+	 * <p>
+	 * @param containerFSRL a reference to the file that contains the file system image
+	 * @param monitor {@link TaskMonitor} to allow the user to cancel
+	 * @return new {@link GFileSystem} instance, caller is responsible for closing() when done.
+	 * @throws CancelledException if user cancels
+	 * @throws IOException if file io error or wrong file system type.
+	 */
+	public GFileSystem openFileSystemContainer(FSRL containerFSRL, TaskMonitor monitor)
+			throws CancelledException, IOException {
+
+		if (localFS.isLocalSubdir(containerFSRL)) {
+			File localDir = localFS.getLocalFile(containerFSRL);
+			return new LocalFileSystemSub(localDir, localFS);
+		}
+
+		File containerFile = getFile(containerFSRL, monitor);
+		return fsFactoryMgr.probe(containerFSRL, containerFile, this, null,
+			FileSystemInfo.PRIORITY_LOWEST, monitor);
+	}
+
 	/**
 	 * Returns a cloned copy of the {@code FSRL} that should have MD5 values specified.
 	 * (excluding GFile objects that don't have data streams)
