@@ -27,6 +27,9 @@ import javax.swing.event.DocumentListener;
 
 import docking.*;
 import docking.event.mouse.GMouseListenerAdapter;
+import docking.widgets.combobox.GComboBox;
+import docking.widgets.label.GDLabel;
+import docking.widgets.label.GLabel;
 import docking.widgets.tree.support.GTreeSelectionEvent;
 import docking.widgets.tree.support.GTreeSelectionListener;
 import ghidra.framework.main.datatree.ClearCutAction;
@@ -562,7 +565,7 @@ public class DataTreeDialog extends DialogComponentProvider
 		JPanel panel = new JPanel();
 		panel.setLayout(new BorderLayout());
 		panel.setBorder(new TitledBorder("Current Projects"));
-		projectComboBox = new JComboBox<>();
+		projectComboBox = new GComboBox<>();
 		DefaultComboBoxModel<String> model = new DefaultComboBoxModel<>();
 		projectComboBox.setModel(model);
 		model.addElement("defaultProject");
@@ -625,7 +628,6 @@ public class DataTreeDialog extends DialogComponentProvider
 			}
 		});
 
-		folderNameLabel = new JLabel("   ");
 		boolean userChoosesName = (type == SAVE) || (type == CREATE);
 		nameField.setEditable(userChoosesName);
 		nameField.setEnabled(userChoosesName);
@@ -633,22 +635,18 @@ public class DataTreeDialog extends DialogComponentProvider
 		// don't put the filter in the dialog when the user can/must type a name, as it's confusing
 		treePanel.setTreeFilterEnabled(!userChoosesName);
 
-		JLabel nameLabel = null;
-		if (type == CHOOSE_FOLDER) {
-			nameLabel = new JLabel("Folder Name:", SwingConstants.RIGHT);
-		}
-		else {
-			nameLabel = new JLabel("Name:", SwingConstants.RIGHT);
-		}
-
 		JPanel namePanel = new JPanel(new PairLayout(2, 5, 100));
 
 		if (!userChoosesName) {
 			namePanel.setBorder(BorderFactory.createEmptyBorder(20, 5, 5, 5));
 		}
-		namePanel.add(new JLabel("Folder Path:", SwingConstants.RIGHT));
+		namePanel.add(new GLabel("Folder Path:", SwingConstants.RIGHT));
+
+		folderNameLabel = new GDLabel("   ");
 		namePanel.add(folderNameLabel);
-		namePanel.add(nameLabel);
+
+		namePanel.add(
+			new GLabel(type == CHOOSE_FOLDER ? "Folder Name:" : "Name:", SwingConstants.RIGHT));
 		namePanel.add(nameField);
 
 		outerPanel.add(namePanel, BorderLayout.CENTER);
