@@ -18,23 +18,24 @@ package ghidra.framework.main;
 import java.awt.BorderLayout;
 import java.awt.Component;
 import java.awt.event.MouseEvent;
-import java.io.*;
+import java.io.File;
+import java.io.IOException;
 import java.net.URL;
 import java.util.*;
 
 import javax.swing.*;
 import javax.swing.border.BevelBorder;
 
-import org.jdom.Document;
-import org.jdom.output.XMLOutputter;
-
 import docking.*;
 import docking.action.DockingAction;
 import docking.action.MenuData;
+import docking.tool.ToolConstants;
+import docking.widgets.OkDialog;
 import docking.widgets.OptionDialog;
 import docking.widgets.dialogs.InputDialog;
 import docking.widgets.filechooser.GhidraFileChooser;
 import docking.widgets.filechooser.GhidraFileChooserMode;
+import docking.widgets.label.*;
 import ghidra.app.plugin.PluginCategoryNames;
 import ghidra.framework.GenericRunInfo;
 import ghidra.framework.client.*;
@@ -46,12 +47,11 @@ import ghidra.framework.model.*;
 import ghidra.framework.options.SaveState;
 import ghidra.framework.plugintool.*;
 import ghidra.framework.plugintool.util.PluginStatus;
-import ghidra.framework.plugintool.util.ToolConstants;
 import ghidra.framework.preferences.Preferences;
 import ghidra.framework.remote.User;
 import ghidra.util.*;
-import ghidra.util.filechooser.*;
-import ghidra.util.xml.GenericXMLOutputter;
+import ghidra.util.filechooser.GhidraFileChooserModel;
+import ghidra.util.filechooser.GhidraFileFilter;
 import resources.ResourceManager;
 
 /**
@@ -101,8 +101,6 @@ public class FrontEndPlugin extends Plugin
 	private LogPanel statusPanel;
 	private String projectName;
 
-	private GhidraFileChooser exportFileChooser;
-
 	private FileActionManager fileActionManager;
 	private ProjectActionManager projectActionManager;
 	private ToolActionManager toolActionManager;
@@ -300,39 +298,10 @@ public class FrontEndPlugin extends Plugin
 		return (FrontEndTool) tool;
 	}
 
-	/**
-	 * Get the component for this plugin.
-	 *
-	 * NOTE: made plugin for JUnits...
-	 */
 	public JComponent getComponent() {
 		return mainGuiPanel;
 	}
 
-	/**
-	 * Get the descriptive name for this plugin.
-	 */
-	public static String getDescriptiveName() {
-		return "Front End";
-	}
-
-	/**
-	 * Get the plugin's description.
-	 */
-	public static String getDescription() {
-		return "Front End Components for Ghidra";
-	}
-
-	/**
-	 * Get the category where this plugin belongs.
-	 */
-	public static String getCategory() {
-		return "FrontEnd";
-	}
-
-	/* (non Javadoc)
-	 * @see ghidra.framework.client.RemoteAdapterListener#connectionStateChanged(java.lang.Object)
-	 */
 	@Override
 	public void connectionStateChanged(final Object adapter) {
 		if (activeProject != null) {
@@ -368,23 +337,23 @@ public class FrontEndPlugin extends Plugin
 			"\nserver may be forced to close as a result.";
 		// @formatter:on
 
-		OptionDialog info = new OptionDialog("Ghidra Server Error", message,
-			OptionDialog.PLAIN_MESSAGE, DISCONNECTED_ICON);
+		OkDialog info = new OkDialog("Ghidra Server Error", message, DISCONNECTED_ICON);
 		info.show(tool.getToolFrame());
 	}
 
 	/**
 	 * Set the project manager; try to reopen the last project that was
 	 * opened.
-	 * @param pm
+	 * @param pm the project manager
 	 */
 	void setProjectManager(ProjectManager pm) {
 		this.projectManager = pm;
 	}
 
 	/**
-	 * sets the handle to the activeProject, as well as updating the
+	 * Sets the handle to the activeProject, as well as updating the
 	 * active data tree to show the new active project's data
+	 * @param project the active project
 	 */
 	void setActiveProject(Project project) {
 
@@ -504,8 +473,11 @@ public class FrontEndPlugin extends Plugin
 	 * general project utility that brings up a file chooser for
 	 * the user to specify a directory and filename that are used
 	 * for the Project location and name
-	 * @param create The mode for the fileChooser to be in: create or open existing
-	 * @param approveButtonText The label for the "Open" button on the file chooser
+	 * 
+	 * @param fileChooser the chooser used to pick the project
+	 * @param mode read-only or not
+	 * @param preferenceName the preference property name used to save the last opened project
+	 * @return the project locator for the opened project 
 	 */
 	ProjectLocator chooseProject(GhidraFileChooser fileChooser, String mode,
 			String preferenceName) {
@@ -535,7 +507,7 @@ public class FrontEndPlugin extends Plugin
 						"Cannot open '" + file.getName() + "' as a Ghidra Project");
 					continue;
 				}
-				if (!NamingUtilities.isValidName(filename)) {
+				if (!NamingUtilities.isValidProjectName(filename)) {
 					Msg.showError(getClass(), tool.getToolFrame(), "Invalid Project Name",
 						filename + " is not a valid project name");
 					continue;
@@ -630,24 +602,10 @@ public class FrontEndPlugin extends Plugin
 		return actionContext;
 	}
 
-	/**
-	 * designates whether the user interface is showing or hidden
-	 * @return true if showing; false if not showing
-	 */
-	final boolean isGuiShowing() {
-		return mainGuiPanel.isShowing();
-	}
-
-	/**
-	 * Get the tool button transferable.
-	 */
 	ToolButtonTransferable getToolButtonTransferable() {
 		return toolButtonTransferable;
 	}
 
-	/**
-	 * Set the tool button transferable.
-	 */
 	void setToolButtonTransferable(ToolButtonTransferable t) {
 		if (t == null && toolButtonTransferable != null) {
 			toolButtonTransferable.clearTransferData();
@@ -683,88 +641,34 @@ public class FrontEndPlugin extends Plugin
 	 * @param msgSource source of status message for successful export
 	 */
 	void exportToolConfig(ToolTemplate template, String msgSource) {
+
+		ToolTemplate updatedTeplate = getUpToDateTemplate(template);
+		ToolServices services = activeProject.getToolServices();
+
 		try {
-			GhidraFileChooser fileChooser = getFileChooser(template);
-
-			File selectedFile = fileChooser.getSelectedFile(true);
-			if (selectedFile == null) { // user cancelled
-				return;
+			File savedFile = services.exportTool(updatedTeplate);
+			if (savedFile != null) {
+				Msg.info(this, msgSource + ": Successfully exported " + updatedTeplate.getName() +
+					" to " + savedFile.getAbsolutePath());
 			}
-
-			Preferences.setProperty(Preferences.LAST_TOOL_EXPORT_DIRECTORY,
-				selectedFile.getParent());
-			if (selectedFile.exists()) {
-				int result = OptionDialog.showOptionDialog(tool.getToolFrame(), "Overwrite?",
-					"File exists. Do you want to overwrite?", "Yes", "No",
-					OptionDialog.QUESTION_MESSAGE);
-
-				// the user chose not to overwrite the file, ask them to choose again
-				// if the user hit yes, then it will be handled below
-				if (result == OptionDialog.OPTION_TWO) {
-					exportToolConfig(template, msgSource);
-					return;
-				}
-			}
-
-			exportToolTemplate(selectedFile, template, msgSource);
-		}
-		catch (IOException e) {
-			Msg.showError(this, tool.getToolFrame(), "Error Exporting Tool",
-				"Error exporting tool: " + e.getMessage(), e);
 		}
 		catch (Exception e) {
-			Msg.showError(this, null, "Error", "Error exporting tool", e);
+			Msg.showError(this, null, "Error Exporting Tool", "Error exporting tool tool", e);
 		}
 	}
 
-	private GhidraFileChooser getFileChooser(ToolTemplate template) {
-		if (exportFileChooser == null) {
-			exportFileChooser = new GhidraFileChooser(tool.getToolFrame());
-			exportFileChooser.setFileFilter(new ExtensionFileFilter("tool", "Tools"));
-			exportFileChooser.setApproveButtonText("Export");
+	private ToolTemplate getUpToDateTemplate(ToolTemplate template) {
 
-			// always prefer the last export directory...
-			String exportDir = Preferences.getProperty(Preferences.LAST_TOOL_EXPORT_DIRECTORY);
-			if (exportDir != null) {
-				exportFileChooser.setCurrentDirectory(new File(exportDir));
-			}
-			else {
-				// ...then try the import directory
-				String importDir = Preferences.getProperty(Preferences.LAST_TOOL_IMPORT_DIRECTORY);
-				if (importDir != null) {
-					exportFileChooser.setCurrentDirectory(new File(importDir));
-				}
+		ToolManager toolManager = activeProject.getToolManager();
+		Tool[] runningTools = toolManager.getRunningTools();
+		String templateName = template.getName();
+		for (Tool runningTool : runningTools) {
+			if (runningTool.getName().equals(templateName)) {
+				return runningTool.getToolTemplate(true);
 			}
 		}
 
-		exportFileChooser.setTitle("Export " + template.getName());
-		return exportFileChooser;
-	}
-
-	/**
-	 * Export the tool.
-	 */
-	private void exportToolTemplate(File location, ToolTemplate template, String msgSource)
-			throws FileNotFoundException, IOException {
-
-		String filename = location.getName();
-		if (filename.endsWith(".tool")) {
-			filename = filename.substring(0, filename.length() - 5);
-		}
-
-		FileOutputStream f =
-			new FileOutputStream(location.getParent() + File.separator + filename + ".tool");
-		BufferedOutputStream bf = new BufferedOutputStream(f);
-
-		Document doc = new Document(template.saveToXml());
-
-		XMLOutputter xmlout = new GenericXMLOutputter();
-		xmlout.output(doc, bf);
-
-		bf.close();
-
-		Msg.info(this, msgSource + ": Successfully exported " + template.getName() + " to " +
-			location.getAbsolutePath());
+		return template;
 	}
 
 	private void updateConnectionPanel(Project project) {
@@ -774,7 +678,7 @@ public class FrontEndPlugin extends Plugin
 			connectionIconPanel.remove(connectionButton);
 		}
 		if (project == null || project.getRepository() == null) {
-			connectionLabel = new JLabel(emptyIcon);
+			connectionLabel = new GIconLabel(emptyIcon);
 			connectionIconPanel.add(connectionLabel);
 			return;
 		}
@@ -924,10 +828,10 @@ public class FrontEndPlugin extends Plugin
 
 		JPanel connectionPanel = new JPanel();
 		connectionPanel.setLayout(new BorderLayout());
-		repositoryLabel = new JLabel("");
+		repositoryLabel = new GDLabel();
 		repositoryLabel.setBorder(BorderFactory.createEmptyBorder(0, 10, 0, 0));
 		connectionIconPanel = new JPanel();
-		connectionLabel = new JLabel("");
+		connectionLabel = new GLabel();
 		connectionIconPanel.add(connectionLabel);
 		connectionPanel.add(repositoryLabel, BorderLayout.CENTER);
 		connectionPanel.add(connectionIconPanel, BorderLayout.EAST);
@@ -968,7 +872,8 @@ public class FrontEndPlugin extends Plugin
 			}
 		};
 		exportToolAction.setPopupMenuData(new MenuData(new String[] { "Export..." }, "tool"));
-		exportToolAction.setHelpLocation(new HelpLocation("Tool", EXPORT_TOOL_ACTION_NAME));
+		exportToolAction.setHelpLocation(
+			new HelpLocation(ToolConstants.TOOL_HELP_TOPIC, EXPORT_TOOL_ACTION_NAME));
 
 		deleteToolAction = new ToolButtonAction(DELETE_TOOL_ACTION_NAME) {
 			@Override
@@ -984,7 +889,8 @@ public class FrontEndPlugin extends Plugin
 
 		};
 		deleteToolAction.setPopupMenuData(new MenuData(new String[] { "Delete..." }, "tool"));
-		deleteToolAction.setHelpLocation(new HelpLocation("Tool", DELETE_TOOL_ACTION_NAME));
+		deleteToolAction.setHelpLocation(
+			new HelpLocation(ToolConstants.TOOL_HELP_TOPIC, DELETE_TOOL_ACTION_NAME));
 
 		closeToolAction = new ToolButtonAction(CLOSE_TOOL_ACTION_NAME) {
 			@Override
@@ -999,7 +905,8 @@ public class FrontEndPlugin extends Plugin
 			}
 		};
 		closeToolAction.setPopupMenuData(new MenuData(new String[] { "Close" }, "tool"));
-		closeToolAction.setHelpLocation(new HelpLocation("Tool", CLOSE_TOOL_ACTION_NAME));
+		closeToolAction.setHelpLocation(
+			new HelpLocation(ToolConstants.TOOL_HELP_TOPIC, CLOSE_TOOL_ACTION_NAME));
 
 		renameToolAction = new ToolButtonAction("Rename Tool") {
 			@Override
@@ -1068,7 +975,8 @@ public class FrontEndPlugin extends Plugin
 			}
 		};
 		renameToolAction.setPopupMenuData(new MenuData(new String[] { "Rename..." }, "tool"));
-		renameToolAction.setHelpLocation(new HelpLocation("Tool", "Rename Tool"));
+		renameToolAction.setHelpLocation(
+			new HelpLocation(ToolConstants.TOOL_HELP_TOPIC, "Rename Tool"));
 
 		propertiesAction = new ToolButtonAction(PROPERTIES_ACTION_NAME) {
 			@Override
@@ -1091,7 +999,8 @@ public class FrontEndPlugin extends Plugin
 		propertiesAction.setPopupMenuData(
 			new MenuData(new String[] { "Configure Plugins..." }, "zproperties"));
 
-		propertiesAction.setHelpLocation(new HelpLocation("Tool", "Configure_Tool"));
+		propertiesAction.setHelpLocation(
+			new HelpLocation(ToolConstants.TOOL_HELP_TOPIC, "Configure_Tool"));
 
 		tool.addLocalAction(frontEndProvider, exportToolAction);
 		tool.addLocalAction(frontEndProvider, renameToolAction);
@@ -1189,7 +1098,8 @@ public class FrontEndPlugin extends Plugin
 		if (defaultToolTemplate == null) {
 			// assume no tools in the tool chest
 			Msg.showInfo(this, tool.getToolFrame(), "Cannot Find Tool",
-				"<html>Cannot find tool to open file: <b>" + domainFile.getName() +
+				"<html>Cannot find tool to open file: <b>" +
+					HTMLUtilities.escapeHTML(domainFile.getName()) +
 					"</b>.<br><br>Make sure you have an appropriate tool installed <br>from the " +
 					"<b>Tools->Import Default Tools...</b> menu.  Alternatively, you can " +
 					"use <b>Tool->Set Tool Associations</b> menu to change how Ghidra " +
