@@ -28,8 +28,9 @@ public interface LanguageProvider extends ExtensionPoint {
 
 	/**
 	 * Returns the language with the given name or null if no language has that name
-	 * @param name the name of the language to be retrieved
-	 * @return the language with the given name
+	 * 
+	 * @param languageId the name of the language to be retrieved
+	 * @return the {@link Language} with the given name
 	 */
 	Language getLanguage(LanguageID languageId);
 
@@ -39,9 +40,16 @@ public interface LanguageProvider extends ExtensionPoint {
 	LanguageDescription[] getLanguageDescriptions();
 
 	/**
-	 * @return true if one of more laguages or language description failed to load
+	 * @return true if one of more languages or language description failed to load
 	 * properly.
 	 */
 	boolean hadLoadFailure();
 
+	/**
+	 * Returns true if the given language has been successfully loaded
+	 * 
+	 * @param languageId the name of the language to be retrieved
+	 * @return true if the given language has been successfully loaded
+	 */
+	boolean isLanguageLoaded(LanguageID languageId);
 }
