@@ -539,16 +539,6 @@ class TemporaryCompilerSpec implements CompilerSpec {
 	public void applyContextSettings(DefaultProgramContext ctx) {
 	}
 
-	@Override
-	public int getCallStackMod() {
-		return newCompilerSpec.getCallStackMod();
-	}
-
-	@Override
-	public int getCallStackShift() {
-		return newCompilerSpec.getCallStackShift();
-	}
-
 	@Override
 	public PrototypeModel[] getCallingConventions() {
 		return new PrototypeModel[0];
