@@ -683,7 +683,7 @@ public class ProgramDiffDetails {
 		ArrayList<Symbol> list = new ArrayList<>();
 		for (Symbol symbol : originalSymbols) {
 			SymbolType symbolType = symbol.getSymbolType();
-			if (symbolType.equals(SymbolType.FUNCTION) || (symbolType.equals(SymbolType.CODE) &&
+			if (symbolType.equals(SymbolType.FUNCTION) || (symbolType.equals(SymbolType.LABEL) &&
 				!symbol.getSource().equals(SourceType.DEFAULT))) {
 				list.add(symbol);
 			}
@@ -935,6 +935,7 @@ public class ProgramDiffDetails {
 				" (flexible array) " + ((comment != null) ? comment : "") + " " + newLine);
 		}
 		else {
+			// TODO: how should we display bitfields?
 			buf.append(indent + "Offset=" + DiffUtility.toSignedHexString(offset) + " " +
 				"Ordinal=" + ordinal + " " + fieldName + " " +
 				actualDt.getMnemonic(actualDt.getDefaultSettings()) + "  " +
@@ -1505,8 +1506,8 @@ public class ProgramDiffDetails {
 	private boolean addSpecificCommentDetails(int commentType, String commentName) {
 		boolean hasCommentDiff = false;
 		try {
-			for (Address p1Address = minP1Address; p1Address
-				.compareTo(maxP1Address) <= 0; p1Address = p1Address.add(1L)) {
+			for (Address p1Address = minP1Address; p1Address.compareTo(
+				maxP1Address) <= 0; p1Address = p1Address.add(1L)) {
 				Address p2Address = SimpleDiffUtility.getCompatibleAddress(p1, p1Address, p2);
 				String noComment = "No " + commentName + ".";
 				String cmt1 = l1.getComment(commentType, p1Address);
@@ -2209,9 +2210,8 @@ public class ProgramDiffDetails {
 			for (String propertyName : names1) {
 				if (cu.hasProperty(propertyName)) {
 					// Handle case where the class for a Saveable property is missing (unsupported).
-					if (cu.getProgram()
-						.getListing()
-						.getPropertyMap(propertyName) instanceof UnsupportedMapDB) {
+					if (cu.getProgram().getListing().getPropertyMap(
+						propertyName) instanceof UnsupportedMapDB) {
 						buf.append(
 							indent2 + propertyName + " is an unsupported property." + newLine);
 						continue;
@@ -2282,8 +2282,8 @@ public class ProgramDiffDetails {
 		BookmarkManager bmm1 = p1.getBookmarkManager();
 		BookmarkManager bmm2 = p2.getBookmarkManager();
 		try {
-			for (Address p1Address = minP1Address; p1Address
-				.compareTo(maxP1Address) <= 0; p1Address = p1Address.add(1)) {
+			for (Address p1Address = minP1Address; p1Address.compareTo(
+				maxP1Address) <= 0; p1Address = p1Address.add(1)) {
 				Address p2Address = SimpleDiffUtility.getCompatibleAddress(p1, p1Address, p2);
 				Bookmark[] marks1 = bmm1.getBookmarks(p1Address);
 				Arrays.sort(marks1, BOOKMARK_COMPARATOR);
