@@ -6,6 +6,7 @@ Loader and plugin for IDA to import a XML PROGRAM file to a database.
 """
 
 import idaapi
+import sys
 import time
 from xml.etree import cElementTree
 
@@ -1519,7 +1520,7 @@ class XmlImporter:
             if self.has_attribute(structure, NAMESPACE) == False:
                 return
             namespace = self.get_attribute(structure, NAMESPACE)
-            name = namspace + '__' + name
+            name = namespace + '__' + name
             name.replace('/','_')
             name.replace('.','_')
             dtyp = idaapi.get_struc_id(name)
@@ -1589,7 +1590,7 @@ class XmlImporter:
             if self.has_attribute(union, NAMESPACE) == False:
                 return
             namespace = self.get_attribute(union, NAMESPACE)
-            name = namspace + '__' + name
+            name = namespace + '__' + name
             name.replace('/','_')
             name.replace('.','_')
             dtyp = idaapi.get_struc_id(name)
