@@ -22,13 +22,12 @@ import java.util.*;
 import java.util.concurrent.atomic.AtomicReference;
 import java.util.stream.Collectors;
 
-import javax.swing.JFrame;
-
 import org.jdom.Element;
 
 import docking.ComponentProvider;
 import docking.DialogComponentProvider;
 import docking.test.AbstractDockingTest;
+import docking.tool.ToolConstants;
 import generic.jar.ResourceFile;
 import generic.test.*;
 import ghidra.app.events.CloseProgramPluginEvent;
@@ -58,7 +57,6 @@ import ghidra.util.*;
 import ghidra.util.datastruct.WeakSet;
 import ghidra.util.exception.*;
 import ghidra.util.task.*;
-import resources.ResourceManager;
 import utilities.util.FileUtilities;
 
 public class TestEnv {
@@ -226,6 +224,10 @@ public class TestEnv {
 	}
 
 	public void closeTool(PluginTool toolToClose, boolean ignoreChanges) {
+		if (toolToClose == tool) {
+			tool = null;
+		}
+
 		extraTools.remove(toolToClose);
 		AbstractGenericTest.executeOnSwingWithoutBlocking(() -> {
 			if (ignoreChanges) {
@@ -328,6 +330,7 @@ public class TestEnv {
 	 * <P>This method is considered sub-standard and users should prefer instead 
 	 * {@link #launchDefaultTool()} or {@link #launchDefaultTool(Program)}.
 	 * 
+	 * @param p the program
 	 * @return the newly shown tool
 	 */
 	public PluginTool showTool(Program p) {
@@ -353,7 +356,7 @@ public class TestEnv {
 
 	/**
 	 * Waits for the first window of the given class.  This method is the same as
-	 * {@link #waitForDialogComponent(Window, Class, int)} with the exception that the parent
+	 * {@link #waitForDialogComponent(Class, int)} with the exception that the parent
 	 * window is assumed to be this instance's tool frame.
 	 *
 	 * @param ghidraClass The class of the dialog the user desires
@@ -365,8 +368,7 @@ public class TestEnv {
 	@Deprecated
 	public <T extends DialogComponentProvider> T waitForDialogComponent(Class<T> ghidraClass,
 			int maxTimeMS) {
-		JFrame frame = lazyTool().getToolFrame();
-		return AbstractDockingTest.waitForDialogComponent(frame, ghidraClass, maxTimeMS);
+		return AbstractDockingTest.waitForDialogComponent(ghidraClass);
 	}
 
 	private static GhidraProject createGhidraTestProject(String projectName) throws IOException {
@@ -377,7 +379,11 @@ public class TestEnv {
 		deleteSavedFrontEndTool();
 
 		String projectDirectoryName = AbstractGTest.getTestDirectoryPath();
-		return GhidraProject.createProject(projectDirectoryName, projectName, true);
+		GhidraProject gp = GhidraProject.createProject(projectDirectoryName, projectName, true);
+
+		installDefaultTool(gp);
+
+		return gp;
 	}
 
 	private static void deleteOldTestTools() {
@@ -395,6 +401,19 @@ public class TestEnv {
 		}
 	}
 
+	private static void installDefaultTool(GhidraProject gp) {
+		// 
+		// Unusual Code Alert: The default tool is not always found in the testing environment,  
+		// depending upon where the test lives.   This code maps the test tool to that tool name
+		// so that tests will have the default tool as needed.
+		// 
+		Project project = gp.getProject();
+		ToolChest toolChest = project.getLocalToolChest();
+		ToolTemplate template = getToolTemplate(AbstractGenericTest.DEFAULT_TEST_TOOL_NAME);
+		template.setName(AbstractGenericTest.DEFAULT_TOOL_NAME);
+		AbstractGenericTest.runSwing(() -> toolChest.replaceToolTemplate(template));
+	}
+
 	private void initializeSimpleTool() {
 
 		if (tool != null) {
@@ -462,6 +481,7 @@ public class TestEnv {
 	/**
 	 * This method differs from {@link #launchDefaultTool()} in that this method does not set the
 	 * <tt>tool</tt> variable in of this <tt>TestEnv</tt> instance.
+	 * @return the tool
 	 */
 	public PluginTool createDefaultTool() {
 		PluginTool newTool = launchDefaultToolByName(AbstractGenericTest.DEFAULT_TEST_TOOL_NAME);
@@ -493,16 +513,15 @@ public class TestEnv {
 		return tool;
 	}
 
-	protected PluginTool launchDefaultToolByName(final String toolName) {
-		AtomicReference<PluginTool> ref = new AtomicReference<>();
-		AbstractGenericTest.runSwing(() -> {
-			// first try the tools in the classpath
-			File toolFile = ResourceManager.getResourceFile("defaultTools/" + toolName + ".tool");
-			if (!toolFile.exists()) {
-				return;
-			}
+	protected PluginTool launchDefaultToolByName(String toolName) {
 
-			ToolTemplate toolTemplate = ToolUtils.readToolTemplate(toolFile);
+		return AbstractGenericTest.runSwing(() -> {
+
+			ToolTemplate toolTemplate = getToolTemplate(toolName);
+			if (toolTemplate == null) {
+				Msg.debug(this, "Unable to find tool: " + toolName);
+				return null;
+			}
 
 			boolean wasErrorGUIEnabled = AbstractDockingTest.isUseErrorGUI();
 			AbstractDockingTest.setErrorGUIEnabled(false); // disable the error GUI while launching the tool
@@ -511,11 +530,23 @@ public class TestEnv {
 			Project project = frontEndToolInstance.getProject();
 			ToolManager toolManager = project.getToolManager();
 			Workspace workspace = toolManager.getActiveWorkspace();
-			ref.set((PluginTool) workspace.runTool(toolTemplate));
 
 			AbstractDockingTest.setErrorGUIEnabled(wasErrorGUIEnabled);
+			return (PluginTool) workspace.runTool(toolTemplate);
+		});
+	}
+
+	private static ToolTemplate getToolTemplate(String toolName) {
+
+		return AbstractGenericTest.runSwing(() -> {
+			ToolTemplate toolTemplate =
+				ToolUtils.readToolTemplate("defaultTools/" + toolName + ToolUtils.TOOL_EXTENSION);
+			if (toolTemplate == null) {
+				Msg.debug(TestEnv.class, "Unable to find tool: " + toolName);
+				return null;
+			}
+			return toolTemplate;
 		});
-		return ref.get();
 	}
 
 	public ScriptTaskListener runScript(File script) throws PluginException {
@@ -546,6 +577,7 @@ public class TestEnv {
 
 	/**
 	 * Returns GhidraProject associated with this environment
+	 * @return the project
 	 */
 	public GhidraProject getGhidraProject() {
 		return gp;
@@ -555,6 +587,7 @@ public class TestEnv {
 	 * A convenience method to close and then reopen the default project created by this TestEnv
 	 * instance.  This will not delete the project between opening and closing and will restore
 	 * the project to its previous state.
+	 * @throws IOException if any exception occurs while saving and reopening
 	 */
 	public void closeAndReopenProject() throws IOException {
 		gp.setDeleteOnClose(false);
@@ -575,9 +608,6 @@ public class TestEnv {
 		return gp.getProjectManager();
 	}
 
-	/**
-	 * Returns Project associated with this environment
-	 */
 	public Project getProject() {
 		return gp.getProject();
 	}
@@ -599,7 +629,7 @@ public class TestEnv {
 	 */
 	public PluginTool launchAnotherDefaultTool() {
 		PluginTool newTool = createDefaultTool();
-		newTool.setToolName(newTool.getToolName() + toolID++);
+		AbstractGenericTest.runSwing(() -> newTool.setToolName(newTool.getToolName() + toolID++));
 		extraTools.add(newTool);
 		return newTool;
 
@@ -642,6 +672,8 @@ public class TestEnv {
 	 * the only reason to use this method vice openProgram().
 	 *
 	 * @param programName the name of the program zip file without the ".gzf" extension.
+	 * @return the restored domain file
+	 * @throws FileNotFoundException if the program file cannot be found
 	 */
 	public DomainFile restoreProgram(String programName) throws FileNotFoundException {
 		DomainFile df = programManager.addProgramToProject(getProject(), programName);
@@ -670,12 +702,12 @@ public class TestEnv {
 	 * @param relativePathName This should be a pathname relative to the "test_resources/testdata"
 	 * 		  director or relative to the "typeinfo" directory. The name should
 	 *        include the ".gdt" suffix.
-	 * @param domainFolder the folder in the test project where the archive should be created.
-	 * @param monitor monitor for canceling this restore.
+	 * @param domainFolder the folder in the test project where the archive should be created
 	 * @return the domain file  that was created in the project
+	 * @throws Exception if an exception occurs
 	 */
 	public DomainFile restoreDataTypeArchive(String relativePathName, DomainFolder domainFolder)
-			throws InvalidNameException, IOException, VersionException {
+			throws Exception {
 
 		File gdtFile;
 		try {
@@ -734,10 +766,10 @@ public class TestEnv {
 	 * @param program program object
 	 * @param replace if true any existing cached database with the same name will be replaced
 	 * @param monitor task monitor
-	 * @throws DuplicateNameException if already cached
+	 * @throws Exception if already cached
 	 */
 	public void saveToCache(String progName, ProgramDB program, boolean replace,
-			TaskMonitor monitor) throws IOException, DuplicateNameException, CancelledException {
+			TaskMonitor monitor) throws Exception {
 
 		programManager.saveToCache(progName, program, replace, monitor);
 	}
@@ -767,7 +799,7 @@ public class TestEnv {
 	 * Open a read-only test program from the test data directory.
 	 * This program must be released prior to disposing this test environment.
 	 * NOTE: Some tests rely on this method returning null when file does
-	 * not yet exist within the resource area (e.g., CUnit binaries for Processor Tests)
+	 * not yet exist within the resource area (e.g., test binaries for P-Code Tests)
 	 *
 	 * @param programName name of program database within the test data directory.
 	 * @return program or null if program file not found
@@ -822,7 +854,8 @@ public class TestEnv {
 	 * Launches a tool of the given name using the given domain file.
 	 * <p>
 	 * Note: the tool returned will have auto save disabled by default.
-	 *
+	 * 
+	 * @param toolName the tool's name
 	 * @return the tool that is launched
 	 */
 	public PluginTool launchTool(String toolName) {
@@ -884,7 +917,7 @@ public class TestEnv {
 	protected void setAutoSaveEnabled(final FrontEndTool frontEndToolInstance,
 			final boolean enabled) {
 		AbstractGenericTest.runSwing(() -> {
-			Options options = frontEndToolInstance.getOptions("Tool");
+			Options options = frontEndToolInstance.getOptions(ToolConstants.TOOL_OPTIONS);
 			options.setBoolean(FrontEndTool.AUTOMATICALLY_SAVE_TOOLS, enabled);
 		});
 	}
@@ -1074,8 +1107,7 @@ public class TestEnv {
 			// so that the tests may limp along if this is not a serious issue--throwing the
 			// exception my prevent other cleanup from taking place.
 			Msg.error(TestEnv.class, "Unable to delete project: " + projectName +
-				" in directory: " + AbstractGTest.getTestDirectoryPath(),
-				new RuntimeException());
+				" in directory: " + AbstractGTest.getTestDirectoryPath(), new RuntimeException());
 		}
 	}
 
@@ -1213,5 +1245,7 @@ public class TestEnv {
 
 		DefaultProjectManager pm = gp.getProjectManager();
 		pm.addDefaultTools(tc);
+
+		installDefaultTool(gp);
 	}
 }
