@@ -22,18 +22,23 @@ import java.io.FileFilter;
 import java.text.SimpleDateFormat;
 import java.util.*;
 import java.util.List;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
 import java.util.stream.Collectors;
 
 import javax.swing.*;
-import javax.swing.border.Border;
-import javax.swing.event.*;
+import javax.swing.event.CellEditorListener;
+import javax.swing.event.ChangeEvent;
 import javax.swing.filechooser.FileSystemView;
 
 import docking.*;
-import docking.framework.DockingApplicationConfiguration;
 import docking.widgets.*;
-import ghidra.GhidraApplicationLayout;
-import ghidra.framework.*;
+import docking.widgets.combobox.GComboBox;
+import docking.widgets.label.GDLabel;
+import docking.widgets.label.GLabel;
+import docking.widgets.list.GListCellRenderer;
+import ghidra.framework.OperatingSystem;
+import ghidra.framework.Platform;
 import ghidra.framework.preferences.Preferences;
 import ghidra.util.Msg;
 import ghidra.util.SystemUtilities;
@@ -67,6 +72,9 @@ import util.HistoryList;
 public class GhidraFileChooser extends DialogComponentProvider
 		implements GhidraFileChooserListener, FileFilter {
 
+	static final String UP_BUTTON_NAME = "UP_BUTTON";
+	private static final Color FOREROUND_COLOR = Color.BLACK;
+	private static final Color BACKGROUND_COLOR = Color.WHITE;
 	static final String PREFERENCES_PREFIX = "G_FILE_CHOOSER";
 	private static final String WIDTH_PREFERENCE_PREFIX = PREFERENCES_PREFIX + ".WIDTH.";
 	private static final String HEIGHT_PREFERENCE_PREFIX = PREFERENCES_PREFIX + ".HEIGHT.";
@@ -82,11 +90,9 @@ public class GhidraFileChooser extends DialogComponentProvider
 	static final String DOT = ".";
 	static final String DOTDOT = "..";
 	static final String NEW_FOLDER = "New Folder";
+	static final Pattern INVALID_FILENAME_PATTERN = Pattern.compile("[/\\\\*?]");
 
 	private static final int PAD = 5;
-	private static final int DEFAULT_ICON_SIZE = 16;
-	private static final int HEIGHT_PADDING = 5;
-	private static final int WIDTH_PADDING = 14;
 
 	private static Icon refreshIcon = Icons.REFRESH_ICON;
 	private static Icon backIcon = ResourceManager.loadImage("images/left.png");
@@ -292,7 +298,7 @@ public class GhidraFileChooser extends DialogComponentProvider
 		myComputerButton.setName("MY_COMPUTER_BUTTON");
 		myComputerButton.setIcon(ResourceManager.loadImage("images/computer.png"));
 		myComputerButton.addActionListener(e -> updateMyComputer());
-		myComputerButton.setForeground(Color.BLACK);
+		myComputerButton.setForeground(FOREROUND_COLOR);
 
 		desktopButton = new FileChooserToggleButton("Desktop") {
 			@Override
@@ -303,7 +309,7 @@ public class GhidraFileChooser extends DialogComponentProvider
 		desktopButton.setName("DESKTOP_BUTTON");
 		desktopButton.setIcon(ResourceManager.loadImage("images/desktop.png"));
 		desktopButton.addActionListener(e -> updateDesktop());
-		desktopButton.setForeground(Color.BLACK);
+		desktopButton.setForeground(FOREROUND_COLOR);
 		desktopButton.setEnabled(fileChooserModel.getDesktopDirectory() != null);
 
 		homeButton = new FileChooserToggleButton("Home") {
@@ -315,7 +321,7 @@ public class GhidraFileChooser extends DialogComponentProvider
 		homeButton.setName("HOME_BUTTON");
 		homeButton.setIcon(ResourceManager.loadImage("images/user-home.png"));
 		homeButton.addActionListener(e -> updateHome());
-		homeButton.setForeground(Color.BLACK);
+		homeButton.setForeground(FOREROUND_COLOR);
 
 		recentButton = new FileChooserToggleButton("Recent") {
 			@Override
@@ -331,7 +337,7 @@ public class GhidraFileChooser extends DialogComponentProvider
 
 		recentButton.setIcon(multiIcon);
 		recentButton.addActionListener(e -> updateRecent());
-		recentButton.setForeground(Color.BLACK);
+		recentButton.setForeground(FOREROUND_COLOR);
 
 		shortCutButtonGroup = new UnselectableButtonGroup();
 		shortCutButtonGroup.add(myComputerButton);
@@ -348,13 +354,13 @@ public class GhidraFileChooser extends DialogComponentProvider
 
 		JPanel panel = new JPanel(new BorderLayout());
 		panel.setBorder(BorderFactory.createLoweredBevelBorder());
-		panel.setBackground(Color.WHITE.darker());
+		panel.setBackground(BACKGROUND_COLOR.darker());
 		panel.add(shortCutPanel, BorderLayout.NORTH);
 		return panel;
 	}
 
 	private JPanel buildFileNamePanel() {
-		JLabel filenameLabel = new JLabel("File name:");
+		JLabel filenameLabel = new GDLabel("File name:");
 		FileDropDownSelectionDataModel model = new FileDropDownSelectionDataModel(this);
 		filenameTextField = new DropDownSelectionTextField<>(model);
 		filenameTextField.setMatchingWindowHeight(200);
@@ -383,28 +389,10 @@ public class GhidraFileChooser extends DialogComponentProvider
 
 		filenameTextField.setName("filenameTextField");
 
-		JLabel filterLabel = new JLabel("Type:");
-		filterCombo = new JComboBox<>();
-		filterCombo.setRenderer(new DefaultListCellRenderer() {
-			private static final long serialVersionUID = 1L;
-
-			@Override
-			public Component getListCellRendererComponent(JList<?> list, Object value, int index,
-					boolean isSelected, boolean cellHasFocus) {
-
-				JLabel label = (JLabel) super.getListCellRendererComponent(list, value, index,
-					isSelected, cellHasFocus);
-				GhidraFileFilter filter = (GhidraFileFilter) value;
-
-				// we can have null filters in the case that the combo box has
-				// no selected item
-				if (filter != null) {
-					label.setText(filter.getDescription());
-				}
-
-				return label;
-			}
-		});
+		JLabel filterLabel = new GLabel("Type:");
+		filterCombo = new GComboBox<>();
+		filterCombo.setRenderer(GListCellRenderer.createDefaultCellTextRenderer(
+			fileFilter -> fileFilter != null ? fileFilter.getDescription() : ""));
 		filterCombo.addItemListener(e -> rescanCurrentDirectory());
 
 		filterModel = (DefaultComboBoxModel<GhidraFileFilter>) filterCombo.getModel();
@@ -467,7 +455,7 @@ public class GhidraFileChooser extends DialogComponentProvider
 	private void buildWaitPanel() {
 		waitPanel = new JPanel(new BorderLayout());
 		waitPanel.setBorder(BorderFactory.createLoweredBevelBorder());
-		waitPanel.setBackground(Color.WHITE);
+		waitPanel.setBackground(BACKGROUND_COLOR);
 		waitPanel.addMouseListener(new MouseAdapter() {
 			@Override
 			public void mouseReleased(MouseEvent e) {
@@ -507,7 +495,7 @@ public class GhidraFileChooser extends DialogComponentProvider
 		forwardButton.addActionListener(e -> goForward());
 
 		upLevelButton = new EmptyBorderButton(upIcon);
-		upLevelButton.setName("UP_BUTTON");
+		upLevelButton.setName(UP_BUTTON_NAME);
 		upLevelButton.setToolTipText("Up one level");
 		upLevelButton.addActionListener(e -> goUpOneDirectoryLevel());
 
@@ -553,6 +541,7 @@ public class GhidraFileChooser extends DialogComponentProvider
 	/**
 	 * When <b>true</b> is passed the chooser will use a detailed table view to show the files;
 	 * false will show a simplified list of files.
+	 * @param showDetails true to show details
 	 */
 	public void setShowDetails(boolean showDetails) {
 		if (detailsButton.isSelected() != showDetails) {
@@ -568,36 +557,12 @@ public class GhidraFileChooser extends DialogComponentProvider
 
 	private JScrollPane buildDirectoryList() {
 		directoryListModel = new DirectoryListModel();
-
-		// SCR 3392 - 12/7/07
-		// initially added to resize the cells of the list when the new files are
-		// inserted into the list (like when creating a single new folder)
-		directoryListModel.addListDataListener(new ListDataListener() {
-			@Override
-			public void contentsChanged(ListDataEvent e) {
-				int size = directoryListModel.getSize();
-				List<File> fileList = new ArrayList<>(size);
-				for (int i = 0; i < size; i++) {
-					fileList.add(directoryListModel.getFile(i));
-				}
-				computeListCellDimensions(fileList);
-			}
-
-			@Override
-			public void intervalAdded(ListDataEvent e) {
-				// don't care
-			}
-
-			@Override
-			public void intervalRemoved(ListDataEvent e) {
-				// don't care
-			}
-		});
 		directoryList = new DirectoryList(this, directoryListModel);
 		directoryList.setName("LIST");
+		directoryList.setBackground(BACKGROUND_COLOR);
 
 		directoryScroll = new JScrollPane(directoryList);
-		directoryScroll.getViewport().setBackground(Color.WHITE);
+		directoryScroll.getViewport().setBackground(BACKGROUND_COLOR);
 		directoryScroll.setVerticalScrollBarPolicy(ScrollPaneConstants.VERTICAL_SCROLLBAR_NEVER);
 		directoryScroll.addComponentListener(new ComponentAdapter() {
 			//if the scroll pane is resized, we need to adjust
@@ -619,18 +584,6 @@ public class GhidraFileChooser extends DialogComponentProvider
 //==================================================================================================
 
 	@Override
-	public ActionContext getActionContext(MouseEvent event) {
-		if (event == null) {
-			return super.getActionContext(event);
-		}
-
-		return new ActionContext(null, event.getSource());
-	}
-
-	/**
-	 * @see ghidra.util.filechooser.GhidraFileChooserListener#modelChanged()
-	 */
-	@Override
 	public void modelChanged() {
 		SystemUtilities.runSwingLater(() -> {
 			directoryListModel.update();
@@ -638,9 +591,6 @@ public class GhidraFileChooser extends DialogComponentProvider
 		});
 	}
 
-	/**
-	 * @see java.io.FileFilter#accept(java.io.File)
-	 */
 	@Override
 	public boolean accept(File file) {
 		if (!showDotFiles) {
@@ -682,7 +632,6 @@ public class GhidraFileChooser extends DialogComponentProvider
 	 *
 	 * @exception IllegalArgumentException  if <code>mode</code> is an
 	 *              illegal Dialog mode
-	 * @see #getFileSelectionMode
 	 * @deprecated use instead {@link #setFileSelectionMode(GhidraFileChooserMode)}
 	 */
 	@Deprecated
@@ -852,54 +801,22 @@ public class GhidraFileChooser extends DialogComponentProvider
 		// the current dir, then we need to update
 		if (force || !directory.equals(currentDirectory)) {
 			worker.schedule(new UpdateDirectoryContentsJob(directory, null, addToHistory));
+			return;
 		}
-		// we only get here if the given dir is the current directory and we are not forcing
-		// an update
-		else {
-			setSelectedFileAndUpdateDisplay((isFilesOnly() ? null : directory));
-		}
+
+		// we only get here if the new dir is the current dir and we are not forcing an update
+		// TODO this code causes unexpected behavior when in 'directories only' mode in that 
+		// this will cause the current directory to change.  The behavior can be seen by 
+		// putting this code back in and then running the tests.   No tests are failing with this
+		// code removed.  We are leaving this code here for a couple releases in case we find 
+		// a code path that requires it.
+		// setSelectedFileAndUpdateDisplay((isFilesOnly() ? null : directory));
 	}
 
 	boolean pendingUpdate() {
 		return worker.isBusy();
 	}
 
-	private void computeListCellDimensions(List<File> files) {
-
-		Font font = directoryList.getFont();
-		FontMetrics metrics = directoryList.getFontMetrics(font);
-
-		int maxWidth = getDefaultMaxWidth(files, metrics);
-
-		directoryList.setFixedCellWidth(maxWidth + DEFAULT_ICON_SIZE + WIDTH_PADDING);
-		int rowHeight = Math.max(metrics.getHeight(), DEFAULT_ICON_SIZE);
-		directoryList.setFixedCellHeight(rowHeight + HEIGHT_PADDING);
-	}
-
-	private int getDefaultMaxWidth(List<File> theFiles, FontMetrics metrics) {
-		int maxWidth = 0;
-		if (theFiles.size() > 0) {
-			for (File file : theFiles) {
-				maxWidth = Math.max(maxWidth, metrics.stringWidth(getDisplayName(file)));
-			}
-			return maxWidth;
-		}
-
-		Dimension scrollSize = directoryScroll.getSize();
-		if (scrollSize.width == 0) {
-			return 0;
-		}
-
-		Border border = directoryScroll.getBorder();
-		if (border != null) {
-			Insets borderInsets = border.getBorderInsets(directoryScroll);
-			if (borderInsets != null) {
-				scrollSize.width -= (borderInsets.right + borderInsets.left);
-			}
-		}
-		return scrollSize.width - WIDTH_PADDING - DEFAULT_ICON_SIZE;
-	}
-
 	String getDisplayName(File file) {
 		if (file != null) {
 			if (GhidraFileChooser.MY_COMPUTER.equals(getCurrentDirectory())) {
@@ -920,8 +837,9 @@ public class GhidraFileChooser extends DialogComponentProvider
 	}
 
 	private void setDirectoryList(File directory, List<File> files) {
+		// if the visible listing is still the same directory as this incoming list of files
 		if (currentDirectory().equals(directory)) {
-			computeListCellDimensions(files);
+			// recompute list cell dims before causing an update to the model
 			directoryTableModel.setFiles(files);
 			directoryTable.scrollRectToVisible(new Rectangle(0, 0, 0, 0));
 			directoryListModel.setFiles(files);
@@ -1099,6 +1017,7 @@ public class GhidraFileChooser extends DialogComponentProvider
 		validatedFiles.setFile(null);
 		initialFile = selectedFiles.getFile();
 		initialFileToSelect = initialFile;
+
 		SystemUtilities.runSwingLater(() -> {
 			File selectedFile = selectedFiles.getFile();
 			if (!fileExists(selectedFile)) {
@@ -1357,6 +1276,7 @@ public class GhidraFileChooser extends DialogComponentProvider
 		if (!created) {
 			Msg.showError(this, rootPanel, "Create Folder Failed",
 				"Unable to create new folder in " + currentDirectory());
+			return;
 		}
 
 		GhidraFile folder =
@@ -1511,9 +1431,10 @@ public class GhidraFileChooser extends DialogComponentProvider
 		directoryTableModel = new DirectoryTableModel(this);
 		directoryTable = new DirectoryTable(this, directoryTableModel);
 		directoryTable.setName("TABLE");
+		directoryTable.setBackground(BACKGROUND_COLOR);
 
 		JScrollPane scrollPane = new JScrollPane(directoryTable);
-		scrollPane.getViewport().setBackground(Color.WHITE);
+		scrollPane.getViewport().setBackground(BACKGROUND_COLOR);
 		return scrollPane;
 	}
 
@@ -1717,6 +1638,7 @@ public class GhidraFileChooser extends DialogComponentProvider
 	 * <b>
 	 * If you don't know how to use this method, then don't call it!
 	 * </b>
+	 * @param file the file chosen by the user
 	 */
 	void userChoseFile(File file) {
 		doChooseFile(file);
@@ -1729,6 +1651,7 @@ public class GhidraFileChooser extends DialogComponentProvider
 	 * <b>
 	 * If you don't know how to use this method, then don't call it!
 	 * </b>
+	 * @param files the files to select
 	 */
 	void userSelectedFiles(List<File> files) {
 		selectedFiles.setFiles(files);
@@ -2188,12 +2111,17 @@ public class GhidraFileChooser extends DialogComponentProvider
 		}
 	}
 
-	public static void main(String[] args) throws Exception {
-
-		GhidraApplicationLayout layout = new GhidraApplicationLayout();
-		Application.initializeApplication(layout, new DockingApplicationConfiguration());
-		GhidraFileChooser chooser = new GhidraFileChooser(null);
-		chooser.show();
-		System.exit(0);
+	String getInvalidFilenameMessage(String filename) {
+		switch (filename) {
+			case ".":
+			case "..":
+				return "Reserved name '" + filename + "'";
+			default:
+				Matcher m = GhidraFileChooser.INVALID_FILENAME_PATTERN.matcher(filename);
+				if (m.find()) {
+					return "Invalid characters: " + m.group();
+				}
+		}
+		return null;
 	}
 }
